#include "ti83plus.inc"
#include "ti83p.h"

.org $4000

; change this to your ID
#define DEVELOPER_ID    $01,$23,$45

EXT_APP = 1           ; This definition is required of all apps

; This is the application header definition area required for all apps.

 .db $80, $0F         ; Field: Program length
 .db 0, 0, 0, 0       ; Length = 0 (N/A for unsigned apps)

#ifdef SIGN_APP
 .db $80, $13         ; Field: Program type
 .db DEVELOPER_ID     ; Type = Developer ID
#else
 .db $80, $12         ; Field: Program type
 .db $01,$04          ; Type = Shareware, TI-83+
#endif

 .db $80, $21         ; Field: App ID
 .db 1         ; Id = 1
 .db $80, $31         ; Field: App Build
 .db 1         ; Build = 1
 .db $80, $48         ; Field: App Name
 .db "Mermaid "       ; Name -- must be 8 characters
 .db $80, $81         ; Field: App Pages
 .db 1         ; App Pages = 1
 .db $80, $90         ; No default splash screen
 .db $03, $26, $09, $04, $04, $6f, $1b, $80      ; Field: Date stamp- 5/12/1999
 .db $02, $0d, $40, $a1, $6b, $99, $f6, $59, $bc, $67   ; Dummy encrypted TI date stamp signature
 .db $f5, $85, $9c, $09, $6c, $0f, $b4, $03, $9b, $c9
 .db $03, $32, $2c, $e0, $03, $20, $e3, $2c, $f4, $2d 
 .db $73, $b4, $27, $c4, $a0, $72, $54, $b9, $ea, $7c 
 .db $3b, $aa, $16, $f6, $77, $83, $7a, $ee, $1a, $d4 
 .db $42, $4c, $6b, $8b, $13, $1f, $bb, $93, $8b, $fc 
 .db $19, $1c, $3c, $ec, $4d, $e5, $75
 .db $80, $7f         ; Field: Program Image length
 .db   0, 0, 0, 0     ; Length = 0, N/A
 .db   0, 0, 0, 0     ; Reserved
 .db   0, 0, 0, 0     ; Reserved
 .db   0, 0, 0, 0     ; Reserved
 .db   0, 0, 0        ; Reserved
#ifndef SIGN_APP
 .db 0      ; add another pad byte if using only 2-byte keyfile
#endif


;  Main app control begins here
StartApp:

saferam1 equ $9872
_grbufclr equ $4BD0

screensize equ 768 ; screen size

 bcall(_grbufclr)
 ld hl,Frame0
 push hl
frameloop:
 pop hl
 call endcheck
 ld a,(hl)
 inc hl
 or a
 jr nz,mpegdec
 ld de,plotsscreen
 call DispRLE
 push hl
 bcall(_grbufcpy)
 jr framewait
mpegdec:
 ld de,saferam1
 call DispRLE
 push hl
 call MPEGdisp
 bcall(_grbufcpy)
framewait:
 ld b,2
 ei
fpsdelay:
 halt
 halt
 halt
 halt
 halt
 halt
 djnz fpsdelay
 jr frameloop
 pop hl
 ret

MPEGdisp:
 ld hl,saferam1
 ld de,plotsscreen
 ld bc,screensize
mpegloop1:
 ld a,(hl)
 ex de,hl
 xor (hl)
 ld (hl),a
 ex de,hl
 inc hl
 inc de
 dec bc
 ld a,b
 or a
 jr nz,mpegloop1
 ld a,c
 or a
 jr nz,mpegloop1
 ret

DispRLE:
 ld bc, screensize 
DispRLEL:
 ld a, (hl) 
 cp $91     
 jr z, DispRLERun  
 ldi        
DispRLEC:
 ret po     
 jr DispRLEL       
DispRLERun:
 inc hl
 inc hl     
 ld a, (hl) 
DispRLERunL:
 dec hl     
 dec a      
 ldi        
 jr nz, DispRLERunL
 inc hl     
 jr DispRLEC
 ret

endcheck:
 push hl
 inc hl
 ld a,(hl)
 or a
 jr nz,notend
 inc hl
 ld a,(hl)
 or a
 jr nz,notend
 inc hl
 ld a,(hl)
 or a
 jr nz,notend
 pop hl
 pop hl
 bcall(_clrScrn2)
 bjump(4027h) ; Exit the 83+ application
 
notend:
 pop hl
 ret
Frame0:
 .db $00
 .db $91,$FF,$F6,$9F,$91,$FF,$0B,$BF
 .db $91,$FF,$17,$9F,$91,$FF,$22,$FC
 .db $0F,$91,$FF,$16,$30,$03,$91,$FF
 .db $47,$FD,$91,$FF,$15,$7F,$FF,$DF
 .db $91,$FF,$09,$7F,$91,$FF,$0A,$EF
 .db $5F,$FB,$7F,$91,$FF,$09,$FE,$FB
 .db $FF,$7F,$91,$FF,$07,$EE,$8E,$FB
 .db $FF,$CA,$EF,$91,$FF,$07,$FE,$FB
 .db $FF,$FF,$EF,$91,$FF,$23,$DF,$91
 .db $FF,$E7
Frame1:
 .db $01
 .db $91,$00,$FF,$91,$00,$FF,$91,$00
 .db $FF,$91,$00,$03
Frame2:
 .db $01
 .db $91,$00,$EA,$20,$91,$00,$0B,$20
 .db $91,$00,$0B,$40,$91,$00,$3B,$10
 .db $91,$00,$77,$20,$91,$00,$20,$10
 .db $91,$00,$0F,$20,$91,$00,$FF,$91
 .db $00,$19
Frame3:
 .db $00
 .db $91,$FF,$78,$F8,$91,$00,$04,$FF
 .db $F0,$91,$00,$04,$3F,$F8,$91,$00
 .db $03,$FF,$FF,$F8,$91,$00,$04,$3F
 .db $F8,$00,$00,$03,$FF,$FF,$FE,$91
 .db $00,$04,$3F,$F8,$00,$00,$07,$91
 .db $FF,$03,$80,$91,$00,$03,$3F,$F8
 .db $00,$00,$0C,$91,$FF,$03,$C0,$91
 .db $00,$03,$3F,$F8,$00,$00,$07,$91
 .db $FF,$03,$E0,$91,$00,$03,$3F,$F8
 .db $00,$00,$07,$91,$FF,$03,$E0,$91
 .db $00,$03,$3F,$F8,$00,$00,$0F,$91
 .db $FF,$03,$F0,$91,$00,$03,$3F,$F8
 .db $00,$00,$1F,$91,$FF,$03,$F0,$91
 .db $00,$03,$3F,$F8,$00,$00,$3F,$91
 .db $FF,$03,$F8,$91,$00,$03,$3F,$F8
 .db $00,$00,$91,$FF,$04,$F8,$91,$00
 .db $03,$3F,$F8,$00,$07,$91,$FF,$04
 .db $F8,$91,$00,$03,$3F,$F8,$00,$07
 .db $91,$FF,$03,$E7,$F8,$91,$00,$03
 .db $3F,$F8,$00,$0F,$91,$FF,$03,$87
 .db $F8,$91,$00,$03,$3F,$F8,$00,$0F
 .db $FF,$FF,$FE,$07,$F0,$91,$00,$03
 .db $3F,$F8,$03,$DF,$FF,$FF,$FC,$07
 .db $F0,$91,$00,$03,$3F,$F8,$19,$5F
 .db $FF,$FF,$D1,$01,$F0,$91,$00,$03
 .db $3F,$F8,$1C,$1F,$FF,$FF,$EF,$3F
 .db $F8,$91,$00,$03,$3F,$F8,$38,$1F
 .db $FF,$FF,$BC,$01,$FC,$91,$00,$03
 .db $3F,$F8,$28,$1F,$FF,$FD,$F8,$1F
 .db $FE,$91,$00,$03,$3F,$F8,$0F,$1F
 .db $FF,$F9,$F0,$7F,$FE,$91,$00,$03
 .db $3F,$F8,$00,$1F,$FF,$FF,$F8,$FF
 .db $FE,$91,$00,$03,$3F,$F8,$00,$0F
 .db $FF,$FA,$F8,$FF,$FE,$91,$00,$03
 .db $3F,$F8,$00,$7F,$FF,$FB,$F8,$FF
 .db $FE,$91,$00,$03,$3F,$F8,$00,$0F
 .db $FF,$F8,$8C,$A3,$FE,$00,$00,$04
 .db $3F,$F8,$00,$03,$FF,$F8,$00,$01
 .db $FE,$00,$00,$04,$3F,$F8,$00,$00
 .db $FF,$E0,$00,$01,$FC,$91,$00,$03
 .db $3F,$F8,$00,$01,$FF,$E0,$02,$41
 .db $F8,$91,$00,$03,$3F,$F8,$00,$09
 .db $FF,$FC,$07,$C1,$F8,$91,$00,$03
 .db $3F,$F8,$00,$0F,$FF,$FC,$00,$01
 .db $FE,$91,$00,$03,$3F,$F8,$00,$0F
 .db $FF,$FC,$00,$01,$FE,$00,$0D,$04
 .db $3F,$F8,$00,$9F,$FF,$FE,$0F,$F3
 .db $FE,$00,$30,$F8,$3F,$F8,$00,$3F
 .db $FF,$FE,$0F,$FF,$FF,$91,$00,$03
 .db $3F,$F8,$01,$7F,$FF,$FF,$0F,$EF
 .db $FF,$80,$00,$00,$3F,$F8,$00,$91
 .db $FF,$03,$83,$DF,$FF,$F8,$00,$00
 .db $3F,$F8,$00,$91,$FF,$03,$C0,$7F
 .db $FF,$FF,$80,$00,$3F,$F8,$01,$FF
 .db $FF,$FE,$F3,$91,$FF,$03,$80,$00
 .db $3F,$F8,$01,$91,$FF,$07,$C0,$00
 .db $3F,$F8,$01,$91,$FF,$04,$FE,$FF
 .db $FF,$E0,$00,$3F,$F9,$91,$FF,$08
 .db $F0,$00,$3F,$91,$FF,$03,$F7,$91
 .db $FF,$05,$FC,$00,$3F,$91,$FF,$06
 .db $FD,$FF,$FF,$FE,$00,$3F,$91,$FF
 .db $06,$FD,$FF,$FF,$FE,$00,$3F,$91
 .db $FF,$0A,$00,$3F,$91,$FF,$0A,$00
 .db $3F,$91,$FF,$6C
Frame4:
 .db $01
 .db $91,$00,$7D,$FF,$F0,$91,$00,$09
 .db $FA,$8F,$F8,$91,$00,$08,$03,$D0
 .db $06,$FE,$91,$00,$08,$07,$D0,$20
 .db $0F,$80,$91,$00,$07,$0C,$F0,$00
 .db $07,$C0,$91,$00,$07,$05,$90,$00
 .db $03,$E0,$91,$00,$07,$04,$00,$00
 .db $01,$60,$91,$00,$06,$30,$0C,$91
 .db $00,$03,$30,$91,$00,$06,$10,$18
 .db $91,$00,$03,$10,$91,$00,$07,$3F
 .db $91,$00,$03,$18,$91,$00,$07,$FC
 .db $91,$00,$03,$08,$91,$00,$06,$01
 .db $78,$91,$00,$0A,$07,$F0,$00,$00
 .db $18,$91,$00,$07,$0F,$E0,$00,$00
 .db $78,$91,$00,$07,$4F,$E0,$00,$01
 .db $F8,$08,$91,$00,$05,$03,$9F,$C0
 .db $00,$03,$F8,$08,$91,$00,$05,$18
 .db $A6,$80,$00,$2E,$FE,$08,$91,$00
 .db $05,$1D,$DC,$40,$00,$10,$D0,$91
 .db $00,$06,$36,$23,$00,$00,$43,$83
 .db $04,$91,$00,$05,$34,$1C,$00,$02
 .db $06,$1E,$02,$91,$00,$05,$1F,$5F
 .db $00,$06,$06,$74,$02,$91,$00,$05
 .db $07,$10,$00,$00,$06,$E0,$0E,$91
 .db $00,$08,$05,$44,$FE,$02,$91,$00
 .db $05,$04,$60,$00,$05,$04,$E0,$02
 .db $91,$00,$06,$30,$00,$07,$70,$BC
 .db $02,$00,$00,$0A,$91,$00,$03,$3C
 .db $00,$07,$BC,$3E,$02,$00,$00,$0C
 .db $91,$00,$03,$3F,$00,$1E,$BE,$3E
 .db $04,$91,$00,$06,$3E,$00,$1F,$F6
 .db $6E,$08,$91,$00,$06,$76,$00,$02
 .db $07,$C0,$08,$91,$00,$06,$F0,$00
 .db $02,$00,$00,$3E,$91,$00,$06,$F0
 .db $00,$02,$01,$40,$3E,$00,$0D,$04
 .db $91,$00,$03,$60,$00,$00,$0E,$00
 .db $3E,$00,$01,$E0,$91,$00,$03,$C0
 .db $00,$00,$06,$1C,$1F,$00,$00,$C0
 .db $00,$00,$01,$80,$91,$00,$03,$1C
 .db $0F,$80,$91,$00,$03,$01,$91,$00
 .db $04,$1D,$E4,$0F,$F9,$91,$00,$03
 .db $02,$F7,$91,$00,$03,$1F,$90,$00
 .db $0E,$80,$00,$00,$07,$C2,$00,$00
 .db $01,$0C,$91,$00,$06,$07,$FE,$91
 .db $00,$07,$C0,$00,$00,$07,$FE,$91
 .db $00,$04,$01,$00,$00,$E0,$00,$00
 .db $06,$91,$00,$08,$70,$91,$00,$05
 .db $08,$00,$00,$08,$00,$00,$1C,$91
 .db $00,$08,$02,$00,$00,$1E,$91,$00
 .db $08,$02,$00,$00,$19,$80,$91,$00
 .db $0A,$0C,$C0,$91,$00,$0B,$80,$91
 .db $00,$6D
Frame5:
 .db $01
 .db $91,$00,$A0,$10,$91,$00,$0B,$10
 .db $00,$04,$91,$00,$08,$02,$78,$00
 .db $03,$80,$91,$00,$07,$01,$F0,$00
 .db $01,$91,$00,$07,$30,$1F,$F0,$91
 .db $00,$09,$10,$18,$C0,$91,$00,$0A
 .db $1F,$91,$00,$03,$10,$91,$00,$07
 .db $0C,$91,$00,$03,$08,$91,$00,$07
 .db $18,$91,$00,$03,$04,$91,$00,$0B
 .db $04,$91,$00,$0B,$04,$91,$00,$0B
 .db $04,$91,$00,$07,$40,$00,$00,$02
 .db $04,$91,$00,$05,$01,$09,$80,$00
 .db $02,$0F,$04,$91,$00,$05,$01,$03
 .db $C0,$00,$00,$0F,$04,$91,$00,$05
 .db $04,$09,$91,$00,$03,$83,$04,$91
 .db $00,$06,$03,$00,$00,$31,$1F,$04
 .db $91,$00,$06,$10,$00,$00,$08,$14
 .db $0C,$91,$00,$06,$5F,$00,$00,$42
 .db $1C,$0C,$91,$00,$06,$0A,$00,$00
 .db $42,$3E,$91,$00,$07,$10,$00,$01
 .db $00,$20,$91,$00,$03,$02,$80,$91
 .db $00,$05,$02,$60,$91,$00,$03,$0A
 .db $00,$00,$01,$00,$00,$02,$42,$40
 .db $91,$00,$03,$08,$91,$00,$03,$40
 .db $00,$02,$DE,$40,$04,$91,$00,$06
 .db $40,$00,$00,$D4,$2C,$08,$91,$00
 .db $11,$01,$91,$00,$03,$01,$A0,$20
 .db $91,$00,$05,$03,$91,$00,$03,$01
 .db $F0,$10,$91,$00,$05,$01,$91,$00
 .db $03,$02,$12,$20,$00,$20,$91,$00
 .db $03,$01,$00,$00,$01,$06,$12,$10
 .db $91,$00,$05,$0F,$91,$00,$03,$10
 .db $91,$00,$06,$01,$07,$91,$00,$03
 .db $11,$C8,$08,$01,$91,$00,$03,$02
 .db $E8,$91,$00,$03,$10,$18,$00,$70
 .db $91,$00,$03,$07,$DC,$91,$00,$03
 .db $08,$10,$00,$01,$80,$00,$00,$07
 .db $C0,$91,$00,$03,$04,$91,$00,$06
 .db $07,$80,$91,$00,$03,$04,$91,$00
 .db $06,$07,$91,$00,$08,$40,$00,$00
 .db $05,$91,$00,$14,$20,$91,$00,$0F
 .db $08,$91,$00,$07,$0C,$91,$00,$0B
 .db $08,$91,$00,$6E
Frame6:
 .db $01
 .db $91,$00,$7E,$40,$91,$00,$0A,$7D
 .db $FE,$91,$00,$0A,$06,$FF,$91,$00
 .db $0A,$20,$0F,$C0,$91,$00,$08,$1C
 .db $00,$03,$F0,$91,$00,$08,$10,$00
 .db $00,$78,$91,$00,$0B,$78,$91,$00
 .db $07,$1C,$10,$00,$00,$38,$91,$00
 .db $07,$1F,$91,$00,$03,$1C,$91,$00
 .db $07,$1F,$80,$00,$00,$0C,$91,$00
 .db $07,$0F,$80,$00,$00,$06,$91,$00
 .db $07,$C0,$91,$00,$03,$03,$91,$00
 .db $07,$0F,$00,$00,$01,$03,$91,$00
 .db $07,$1E,$00,$00,$03,$83,$91,$00
 .db $07,$1E,$00,$00,$07,$83,$80,$91
 .db $00,$06,$5C,$00,$00,$0D,$83,$80
 .db $91,$00,$05,$AA,$FC,$00,$02,$0F
 .db $03,$80,$91,$00,$05,$D3,$A8,$00
 .db $04,$19,$03,$80,$91,$00,$04,$0A
 .db $D5,$F0,$00,$00,$F9,$83,$80,$91
 .db $00,$04,$12,$0E,$A0,$00,$30,$C1
 .db $07,$80,$91,$00,$03,$06,$1E,$51
 .db $00,$00,$01,$60,$0F,$91,$00,$05
 .db $11,$38,$C0,$00,$53,$7C,$03,$91
 .db $00,$05,$10,$05,$C0,$00,$41,$20
 .db $02,$91,$00,$05,$04,$08,$40,$00
 .db $7C,$2C,$03,$00,$00,$02,$80,$00
 .db $01,$F0,$40,$00,$3E,$7F,$03,$00
 .db $00,$08,$00,$00,$01,$38,$C0,$02
 .db $70,$77,$83,$80,$91,$00,$05,$70
 .db $C0,$03,$E0,$47,$83,$91,$00,$05
 .db $0C,$60,$00,$00,$E0,$3B,$87,$91
 .db $00,$05,$0C,$60,$00,$01,$E2,$FD
 .db $0F,$91,$00,$05,$01,$E0,$00,$01
 .db $E2,$5C,$1E,$91,$00,$05,$03,$E0
 .db $00,$01,$E3,$6E,$2E,$00,$06,$91
 .db $00,$03,$0D,$C0,$00,$01,$F8,$1E
 .db $1E,$00,$03,$08,$00,$00,$4D,$C0
 .db $00,$00,$F6,$0E,$0E,$00,$01,$91
 .db $00,$03,$0F,$C0,$00,$00,$E3,$EC
 .db $0F,$80,$91,$00,$04,$07,$C0,$00
 .db $00,$49,$EC,$07,$80,$91,$00,$04
 .db $1F,$40,$00,$00,$20,$08,$00,$01
 .db $91,$00,$04,$1F,$80,$00,$00,$18
 .db $90,$00,$07,$91,$00,$04,$3E,$02
 .db $00,$00,$04,$80,$00,$03,$91,$00
 .db $04,$78,$02,$00,$C0,$04,$00,$01
 .db $01,$91,$00,$04,$F0,$00,$03,$80
 .db $91,$00,$04,$C0,$00,$00,$02,$88
 .db $00,$04,$80,$00,$08,$00,$00,$20
 .db $91,$00,$0B,$60,$00,$00,$06,$91
 .db $00,$08,$66,$80,$00,$00,$08,$91
 .db $00,$07,$0C,$40,$91,$00,$0A,$08
 .db $80,$91,$00,$6D
Frame7:
 .db $01
 .db $91,$00,$7E,$40,$91,$00,$0B,$06
 .db $91,$00,$21,$06,$00,$00,$10,$91
 .db $00,$2B,$02,$20,$00,$00,$04,$91
 .db $00,$1F,$01,$91,$00,$17,$01,$91
 .db $00,$22,$40,$91,$00,$03,$08,$91
 .db $00,$06,$01,$91,$00,$03,$07,$24
 .db $91,$00,$06,$04,$00,$08,$00,$10
 .db $20,$91,$00,$06,$0B,$00,$A0,$00
 .db $20,$91,$00,$07,$10,$00,$80,$00
 .db $00,$08,$91,$00,$07,$28,$C0,$00
 .db $40,$91,$00,$07,$10,$91,$00,$04
 .db $20,$91,$00,$06,$04,$06,$91,$00
 .db $03,$02,$01,$91,$00,$06,$30,$00
 .db $00,$40,$10,$00,$80,$00,$04,$91
 .db $00,$03,$07,$40,$01,$40,$00,$80
 .db $91,$00,$06,$0F,$40,$00,$40,$00
 .db $00,$80,$91,$00,$05,$13,$C0,$00
 .db $00,$10,$00,$80,$91,$00,$05,$11
 .db $00,$00,$02,$00,$00,$80,$00,$02
 .db $91,$00,$03,$11,$91,$00,$04,$01
 .db $80,$91,$00,$08,$10,$00,$01,$00
 .db $06,$91,$00,$04,$20,$00,$00,$08
 .db $91,$00,$03,$02,$91,$00,$08,$88
 .db $01,$00,$00,$40,$00,$00,$04,$20
 .db $00,$00,$03,$91,$00,$08,$20,$00
 .db $00,$01,$80,$91,$00,$0A,$20,$91
 .db $00,$08,$40,$00,$00,$20,$80,$91
 .db $00,$07,$02,$91,$00,$05,$06,$91
 .db $00,$04,$04,$00,$00,$80,$91,$00
 .db $09,$04,$03,$40,$91,$00,$0A,$04
 .db $91,$00,$11,$C0,$91,$00,$0B,$71
 .db $91,$00,$0B,$2B,$80,$91,$00,$0A
 .db $07,$91,$00,$6E
Frame8:
 .db $01
 .db $91,$00,$88,$05,$00,$40,$91,$00
 .db $09,$20,$80,$91,$00,$0A,$34,$80
 .db $91,$00,$0A,$04,$00,$00,$10,$91
 .db $00,$20,$10,$91,$00,$0A,$02,$20
 .db $91,$00,$21,$06,$5E,$80,$91,$00
 .db $19,$04,$91,$00,$07,$40,$91,$00
 .db $0B,$40,$20,$91,$00,$0A,$1A,$91
 .db $00,$0B,$12,$10,$00,$02,$04,$91
 .db $00,$08,$18,$00,$00,$10,$91,$00
 .db $06,$08,$10,$30,$00,$00,$40,$91
 .db $00,$05,$06,$14,$01,$91,$00,$03
 .db $48,$91,$00,$06,$04,$40,$80,$00
 .db $40,$91,$00,$0B,$40,$91,$00,$07
 .db $0C,$01,$80,$00,$40,$11,$91,$00
 .db $07,$80,$00,$00,$40,$10,$91,$00
 .db $03,$08,$91,$00,$05,$01,$0E,$00
 .db $80,$91,$00,$11,$0C,$0C,$40,$00
 .db $00,$14,$91,$00,$06,$08,$0F,$91
 .db $00,$03,$04,$00,$80,$00,$02,$91
 .db $00,$09,$80,$91,$00,$05,$03,$91
 .db $00,$03,$20,$01,$91,$00,$05,$0C
 .db $20,$00,$00,$02,$91,$00,$07,$0C
 .db $91,$00,$05,$01,$00,$80,$91,$00
 .db $03,$04,$91,$00,$03,$01,$10,$00
 .db $80,$91,$00,$09,$80,$91,$00,$07
 .db $20,$91,$00,$0E,$30,$80,$00,$08
 .db $91,$00,$04,$01,$91,$00,$0B,$02
 .db $04,$00,$18,$04,$00,$42,$91,$00
 .db $06,$04,$00,$88,$00,$01,$00,$00
 .db $C0,$91,$00,$03,$80,$08,$01,$00
 .db $00,$03,$E0,$00,$40,$00,$00,$06
 .db $80,$91,$00,$04,$0E,$00,$00,$60
 .db $00,$00,$07,$91,$00,$08,$70,$91
 .db $00,$0B,$38,$91,$00,$0B,$18,$91
 .db $00,$6E
Frame9:
 .db $01
 .db $91,$00,$88,$05,$00,$60,$91,$00
 .db $09,$20,$80,$91,$00,$0A,$24,$80
 .db $00,$20,$91,$00,$08,$01,$91,$00
 .db $17,$10,$91,$00,$0E,$04,$91,$00
 .db $08,$20,$00,$00,$04,$91,$00,$08
 .db $40,$91,$00,$0E,$01,$91,$00,$06
 .db $06,$5C,$91,$00,$0F,$80,$80,$91
 .db $00,$0A,$40,$80,$91,$00,$05,$40
 .db $01,$91,$00,$0A,$40,$22,$91,$00
 .db $0A,$1A,$91,$00,$03,$08,$91,$00
 .db $07,$12,$34,$00,$05,$45,$80,$91
 .db $00,$07,$08,$00,$00,$C5,$80,$91
 .db $00,$05,$08,$10,$28,$00,$00,$B0
 .db $91,$00,$06,$10,$01,$10,$00,$00
 .db $C0,$00,$80,$91,$00,$05,$2C,$E0
 .db $00,$10,$40,$01,$91,$00,$06,$40
 .db $20,$00,$26,$20,$02,$91,$00,$05
 .db $0C,$02,$20,$91,$00,$03,$01,$91
 .db $00,$06,$80,$60,$00,$C0,$0C,$91
 .db $00,$03,$0C,$91,$00,$04,$40,$00
 .db $0A,$0C,$91,$00,$08,$60,$00,$00
 .db $04,$91,$00,$06,$0C,$00,$40,$00
 .db $00,$2C,$91,$00,$06,$08,$01,$C0
 .db $00,$00,$04,$00,$80,$00,$02,$91
 .db $00,$03,$0E,$C0,$00,$10,$02,$00
 .db $80,$91,$00,$05,$1C,$A0,$00,$02
 .db $02,$01,$80,$04,$10,$00,$00,$4C
 .db $0F,$60,$00,$18,$00,$01,$91,$00
 .db $05,$0C,$3D,$C0,$00,$05,$88,$01
 .db $91,$00,$05,$04,$5F,$80,$00,$10
 .db $91,$00,$08,$1E,$00,$00,$24,$91
 .db $00,$06,$04,$91,$00,$04,$2E,$00
 .db $00,$40,$91,$00,$05,$28,$00,$00
 .db $08,$91,$00,$08,$80,$00,$00,$40
 .db $91,$00,$07,$01,$86,$00,$AE,$04
 .db $00,$42,$91,$00,$08,$98,$91,$00
 .db $04,$C0,$91,$00,$04,$08,$00,$90
 .db $00,$00,$E0,$00,$80,$91,$00,$08
 .db $0C,$91,$00,$0E,$02,$91,$00,$0B
 .db $23,$80,$91,$00,$0A,$07,$91,$00
 .db $6E
Frame10:
 .db $01
 .db $91,$00,$7C,$07,$FF,$FF,$FE,$91
 .db $00,$08,$0A,$F2,$27,$FF,$91,$00
 .db $08,$30,$00,$00,$FF,$80,$91,$00
 .db $07,$10,$00,$00,$1F,$80,$91,$00
 .db $07,$3F,$00,$00,$0F,$C0,$91,$00
 .db $07,$78,$00,$00,$C7,$C0,$91,$00
 .db $07,$E0,$00,$01,$E7,$C0,$91,$00
 .db $07,$F0,$00,$03,$F3,$E0,$91,$00
 .db $07,$E0,$00,$17,$F3,$E0,$91,$00
 .db $06,$02,$C0,$00,$06,$33,$E0,$91
 .db $00,$06,$03,$80,$00,$DF,$80,$C0
 .db $91,$00,$05,$06,$5B,$80,$00,$1F
 .db $C0,$C0,$91,$00,$06,$0F,$00,$00
 .db $1D,$80,$91,$00,$07,$0F,$00,$04
 .db $1B,$C1,$80,$91,$00,$05,$40,$0F
 .db $00,$04,$13,$07,$80,$91,$00,$05
 .db $40,$0E,$00,$00,$13,$87,$80,$91
 .db $00,$05,$1A,$04,$00,$03,$FF,$E3
 .db $80,$91,$00,$04,$01,$63,$F4,$00
 .db $07,$9C,$63,$80,$91,$00,$04,$04
 .db $E0,$28,$00,$17,$0E,$F1,$80,$91
 .db $00,$04,$08,$D2,$E0,$00,$27,$2C
 .db $E1,$80,$91,$00,$04,$13,$01,$20
 .db $00,$03,$F0,$E1,$80,$91,$00,$04
 .db $13,$2C,$18,$00,$03,$20,$E1,$91
 .db $00,$05,$08,$48,$18,$00,$25,$20
 .db $C3,$91,$00,$05,$02,$02,$18,$00
 .db $3E,$7F,$80,$80,$91,$00,$05,$CF
 .db $DC,$00,$FF,$33,$80,$91,$00,$07
 .db $38,$00,$35,$3B,$80,$91,$00,$07
 .db $18,$00,$39,$23,$80,$91,$00,$05
 .db $0C,$00,$20,$00,$3C,$D3,$80,$91
 .db $00,$05,$08,$91,$00,$03,$1C,$1F
 .db $91,$00,$03,$02,$91,$00,$04,$40
 .db $00,$0B,$C0,$91,$00,$03,$60,$91
 .db $00,$04,$20,$00,$11,$D2,$00,$80
 .db $04,$10,$00,$00,$4C,$00,$A0,$00
 .db $09,$E0,$00,$00,$30,$70,$00,$00
 .db $0C,$02,$40,$00,$1C,$E8,$00,$80
 .db $82,$91,$00,$03,$04,$43,$00,$50
 .db $0E,$04,$00,$80,$91,$00,$05,$01
 .db $80,$78,$23,$1D,$00,$40,$91,$00
 .db $03,$06,$00,$9F,$80,$7E,$62,$FE
 .db $C0,$91,$00,$04,$04,$00,$17,$80
 .db $7F,$F4,$60,$00,$33,$91,$00,$05
 .db $7E,$80,$FC,$00,$80,$00,$06,$91
 .db $00,$05,$7C,$00,$0F,$20,$01,$11
 .db $06,$91,$00,$04,$0B,$FF,$01,$D0
 .db $00,$02,$00,$03,$91,$00,$04,$CC
 .db $01,$C1,$D0,$00,$00,$C0,$01,$91
 .db $00,$03,$01,$80,$91,$00,$04,$1E
 .db $91,$00,$05,$07,$80,$91,$00,$04
 .db $04,$00,$00,$82,$91,$00,$0B,$43
 .db $80,$91,$00,$0A,$07,$91,$00,$6E
Frame11:
 .db $01
 .db $91,$00,$7C,$08,$91,$00,$0B,$10
 .db $91,$00,$03,$80,$91,$00,$07,$20
 .db $91,$00,$1B,$40,$91,$00,$09,$01
 .db $20,$91,$00,$08,$80,$00,$02,$00
 .db $40,$91,$00,$06,$02,$00,$00,$0C
 .db $91,$00,$0B,$70,$00,$20,$91,$00
 .db $06,$01,$00,$00,$08,$30,$20,$91
 .db $00,$08,$01,$C0,$40,$91,$00,$0A
 .db $01,$40,$91,$00,$07,$04,$00,$00
 .db $18,$91,$00,$0A,$04,$18,$80,$91
 .db $00,$07,$08,$91,$00,$03,$84,$91
 .db $00,$07,$20,$00,$00,$C0,$70,$91
 .db $00,$07,$08,$91,$00,$03,$10,$91
 .db $00,$06,$48,$18,$00,$08,$00,$02
 .db $91,$00,$07,$20,$00,$04,$91,$00
 .db $07,$0D,$00,$18,$00,$04,$08,$91
 .db $00,$06,$04,$01,$30,$91,$00,$03
 .db $80,$91,$00,$05,$0C,$00,$78,$00
 .db $00,$20,$C0,$91,$00,$05,$0C,$00
 .db $38,$00,$02,$00,$C0,$80,$91,$00
 .db $04,$04,$00,$18,$00,$01,$E0,$91
 .db $00,$07,$40,$FC,$00,$00,$F0,$80
 .db $91,$00,$07,$18,$00,$02,$F6,$91
 .db $00,$08,$08,$00,$01,$9E,$91,$00
 .db $0B,$BC,$91,$00,$08,$20,$00,$04
 .db $DC,$91,$00,$08,$40,$00,$08,$38
 .db $91,$00,$08,$60,$00,$60,$30,$91
 .db $00,$0A,$60,$00,$01,$91,$00,$03
 .db $40,$00,$00,$01,$40,$00,$60,$0C
 .db $00,$80,$91,$00,$04,$04,$03,$40
 .db $31,$E0,$09,$00,$80,$91,$00,$06
 .db $40,$47,$C0,$02,$C0,$40,$91,$00
 .db $03,$03,$91,$00,$03,$01,$82,$C1
 .db $20,$40,$91,$00,$03,$04,$00,$01
 .db $80,$00,$02,$C0,$91,$00,$08,$C0
 .db $91,$00,$0A,$02,$80,$84,$A0,$00
 .db $00,$04,$91,$00,$06,$80,$91,$00
 .db $04,$04,$91,$00,$06,$41,$91,$00
 .db $09,$80,$91,$00,$04,$20,$00,$00
 .db $40,$00,$00,$01,$91,$00,$8F
Frame12:
 .db $01
 .db $91,$00,$8C,$80,$91,$00,$13,$20
 .db $91,$00,$19,$02,$91,$00,$0B,$04
 .db $10,$40,$91,$00,$06,$02,$00,$00
 .db $20,$91,$00,$0B,$60,$88,$91,$00
 .db $0A,$01,$91,$00,$0A,$03,$10,$20
 .db $91,$00,$07,$44,$80,$00,$10,$91
 .db $00,$08,$08,$00,$00,$08,$91,$00
 .db $08,$08,$00,$01,$08,$91,$00,$07
 .db $40,$04,$00,$00,$C8,$80,$91,$00
 .db $06,$40,$2C,$00,$01,$20,$94,$91
 .db $00,$06,$50,$10,$00,$02,$91,$00
 .db $09,$20,$00,$0A,$00,$10,$91,$00
 .db $07,$40,$00,$00,$03,$91,$00,$06
 .db $04,$00,$20,$00,$02,$0B,$91,$00
 .db $06,$08,$02,$91,$00,$03,$30,$91
 .db $00,$06,$0C,$01,$40,$00,$02,$00
 .db $60,$91,$00,$06,$14,$40,$00,$00
 .db $20,$C0,$91,$00,$05,$04,$00,$60
 .db $00,$00,$10,$80,$91,$00,$06,$FC
 .db $40,$00,$00,$48,$91,$00,$08,$20
 .db $00,$01,$08,$91,$00,$08,$30,$00
 .db $04,$F2,$91,$00,$06,$0C,$00,$20
 .db $00,$02,$40,$91,$00,$06,$08,$00
 .db $20,$00,$04,$20,$91,$00,$0A,$10
 .db $00,$00,$80,$91,$00,$06,$20,$02
 .db $40,$10,$01,$91,$00,$05,$0C,$30
 .db $20,$02,$80,$10,$00,$00,$08,$91
 .db $00,$03,$0C,$22,$80,$01,$80,$1C
 .db $03,$91,$00,$08,$6E,$07,$00,$C1
 .db $91,$00,$04,$01,$91,$00,$03,$20
 .db $07,$E0,$31,$80,$91,$00,$03,$06
 .db $00,$08,$C0,$60,$03,$20,$10,$42
 .db $91,$00,$06,$40,$00,$01,$E8,$91
 .db $00,$06,$40,$00,$00,$80,$40,$00
 .db $00,$08,$91,$00,$06,$40,$00,$00
 .db $02,$10,$04,$91,$00,$04,$01,$80
 .db $01,$00,$00,$03,$00,$02,$91,$00
 .db $04,$0C,$00,$61,$40,$00,$02,$C0
 .db $91,$00,$0A,$3C,$00,$00,$40,$91
 .db $00,$08,$04,$00,$01,$42,$91,$00
 .db $0B,$1F,$91,$00,$0B,$02,$91,$00
 .db $6E
Frame13:
 .db $01
 .db $91,$00,$7C,$0C,$00,$00,$01,$80
 .db $91,$00,$07,$1C,$91,$00,$03,$80
 .db $91,$00,$07,$38,$91,$00,$0B,$10
 .db $91,$00,$0B,$30,$91,$00,$0A,$01
 .db $E0,$00,$03,$E0,$40,$91,$00,$07
 .db $40,$00,$07,$F0,$40,$91,$00,$06
 .db $01,$00,$00,$2F,$30,$60,$91,$00
 .db $09,$06,$98,$40,$91,$00,$06,$03
 .db $00,$00,$0E,$E0,$40,$91,$00,$08
 .db $02,$0E,$00,$40,$91,$00,$06,$5C
 .db $80,$00,$0F,$60,$20,$91,$00,$06
 .db $7C,$91,$00,$04,$60,$91,$00,$03
 .db $01,$00,$00,$78,$00,$01,$02,$81
 .db $F0,$91,$00,$05,$40,$FC,$00,$00
 .db $D0,$83,$F0,$91,$00,$03,$01,$80
 .db $43,$DC,$00,$05,$E0,$E3,$F8,$91
 .db $00,$05,$57,$E0,$00,$06,$03,$F3
 .db $F8,$91,$00,$05,$27,$C0,$00,$02
 .db $00,$31,$F8,$91,$00,$05,$0F,$A0
 .db $00,$04,$00,$31,$F8,$91,$00,$04
 .db $C3,$63,$C0,$00,$02,$06,$21,$F0
 .db $91,$00,$04,$41,$8C,$80,$00,$00
 .db $39,$61,$E0,$91,$00,$04,$45,$8E
 .db $40,$00,$03,$C0,$40,$E0,$91,$00
 .db $05,$E3,$80,$00,$01,$E9,$C0,$60
 .db $91,$00,$04,$06,$5F,$80,$00,$01
 .db $F2,$91,$00,$06,$10,$53,$40,$00
 .db $00,$78,$91,$00,$03,$04,$00,$00
 .db $1C,$1F,$C0,$03,$E0,$7E,$07,$80
 .db $91,$00,$04,$2F,$FF,$C0,$03,$FC
 .db $B4,$1F,$80,$91,$00,$04,$13,$FF
 .db $C0,$03,$FE,$40,$07,$80,$91,$00
 .db $04,$33,$FF,$C0,$07,$FC,$33,$C7
 .db $80,$91,$00,$04,$0F,$FF,$C0,$07
 .db $E0,$03,$F7,$00,$00,$A0,$00,$00
 .db $07,$FF,$C0,$05,$C0,$4F,$E2,$91
 .db $00,$04,$07,$0B,$FF,$E0,$0D,$01
 .db $CF,$F6,$00,$00,$A0,$40,$00,$4B
 .db $DC,$40,$0E,$08,$47,$F4,$02,$05
 .db $80,$00,$01,$01,$FF,$C0,$00,$E1
 .db $02,$32,$91,$00,$04,$01,$83,$FF
 .db $C0,$11,$FB,$E0,$F2,$04,$91,$00
 .db $03,$07,$03,$F7,$40,$01,$FE,$DF
 .db $F0,$44,$91,$00,$05,$38,$40,$63
 .db $FF,$C8,$00,$06,$91,$00,$04,$40
 .db $F9,$80,$62,$00,$03,$B0,$0C,$91
 .db $00,$04,$03,$09,$4C,$7D,$80,$04
 .db $80,$08,$91,$00,$04,$01,$7F,$BD
 .db $80,$00,$01,$80,$06,$91,$00,$04
 .db $28,$11,$E1,$80,$00,$01,$00,$02
 .db $91,$00,$0B,$01,$91,$00,$04,$80
 .db $91,$00,$06,$01,$42,$91,$00,$0B
 .db $9F,$91,$00,$0B,$E2,$91,$00,$6E
Frame14:
 .db $01
 .db $91,$00,$7C,$03,$00,$00,$0F,$80
 .db $91,$00,$07,$02,$00,$00,$0F,$80
 .db $91,$00,$07,$04,$00,$00,$07,$80
 .db $91,$00,$07,$28,$00,$00,$03,$80
 .db $91,$00,$07,$08,$00,$00,$01,$80
 .db $91,$00,$06,$01,$90,$91,$00,$03
 .db $80,$91,$00,$06,$02,$30,$00,$01
 .db $00,$80,$91,$00,$06,$01,$C0,$00
 .db $07,$40,$80,$91,$00,$07,$C0,$00
 .db $0F,$60,$80,$91,$00,$07,$C0,$00
 .db $0D,$E0,$80,$00,$00,$C0,$91,$00
 .db $05,$01,$FE,$E0,$91,$00,$07,$58
 .db $00,$00,$1E,$E0,$20,$00,$00,$40
 .db $06,$00,$00,$78,$00,$00,$30,$00
 .db $20,$91,$00,$03,$01,$00,$00,$30
 .db $00,$04,$06,$00,$70,$91,$00,$06
 .db $F0,$00,$00,$14,$00,$F0,$91,$00
 .db $03,$01,$80,$03,$F0,$00,$03,$84
 .db $01,$F8,$91,$00,$04,$80,$07,$F0
 .db $00,$00,$07,$81,$F8,$91,$00,$04
 .db $40,$03,$40,$00,$00,$06,$47,$F8
 .db $91,$00,$04,$40,$8F,$20,$91,$00
 .db $03,$47,$F8,$91,$00,$04,$84,$24
 .db $10,$00,$04,$38,$43,$F0,$91,$00
 .db $04,$45,$0F,$CC,$00,$00,$F9,$03
 .db $20,$91,$00,$04,$44,$8F,$FD,$00
 .db $03,$82,$01,$E0,$91,$00,$04,$04
 .db $8F,$FF,$00,$00,$8B,$00,$E0,$91
 .db $00,$05,$5F,$E6,$00,$01,$A6,$00
 .db $80,$91,$00,$04,$11,$27,$EE,$00
 .db $C2,$10,$91,$00,$03,$54,$00,$00
 .db $1C,$13,$FC,$00,$18,$80,$07,$80
 .db $91,$00,$04,$2F,$F2,$10,$00,$00
 .db $D8,$1F,$80,$00,$80,$00,$00,$1F
 .db $70,$00,$02,$00,$60,$07,$80,$00
 .db $40,$00,$00,$3F,$20,$91,$00,$03
 .db $1C,$C7,$80,$91,$00,$04,$4F,$91
 .db $00,$04,$44,$37,$80,$01,$40,$00
 .db $07,$46,$91,$00,$03,$01,$80,$23
 .db $80,$00,$08,$00,$06,$06,$00,$00
 .db $08,$60,$20,$17,$81,$C3,$C0,$80
 .db $00,$06,$00,$00,$08,$78,$40,$14
 .db $06,$02,$00,$00,$01,$06,$00,$00
 .db $08,$26,$01,$34,$91,$00,$05,$8C
 .db $00,$00,$09,$87,$8F,$07,$04,$91
 .db $00,$04,$1C,$00,$00,$11,$03,$C0
 .db $00,$06,$91,$00,$04,$3F,$C6,$00
 .db $1C,$91,$00,$03,$24,$91,$00,$04
 .db $7F,$07,$C0,$1E,$00,$01,$B0,$08
 .db $91,$00,$04,$7C,$F7,$8C,$00,$00
 .db $05,$80,$91,$00,$05,$7B,$00,$3D
 .db $80,$00,$37,$80,$04,$60,$91,$00
 .db $03,$E0,$10,$01,$91,$00,$09,$80
 .db $91,$00,$06,$02,$91,$00,$0B,$03
 .db $91,$00,$03,$04,$91,$00,$07,$03
 .db $91,$00,$0B,$01,$91,$00,$6F
Frame15:
 .db $01
 .db $91,$00,$7D,$C0,$00,$10,$91,$00
 .db $08,$01,$91,$00,$0E,$08,$91,$00
 .db $08,$24,$00,$00,$04,$91,$00,$0B
 .db $02,$91,$00,$08,$08,$00,$00,$01
 .db $91,$00,$08,$08,$00,$01,$01,$91
 .db $00,$07,$01,$10,$91,$00,$0B,$20
 .db $00,$11,$91,$00,$08,$02,$91,$00
 .db $03,$C0,$91,$00,$0A,$01,$91,$00
 .db $08,$04,$91,$00,$03,$40,$40,$91
 .db $00,$0B,$40,$91,$00,$06,$48,$00
 .db $04,$34,$91,$00,$08,$08,$91,$00
 .db $04,$80,$91,$00,$06,$08,$91,$00
 .db $03,$01,$91,$00,$07,$08,$00,$04
 .db $0D,$81,$91,$00,$06,$02,$38,$00
 .db $04,$06,$06,$91,$00,$06,$80,$20
 .db $91,$00,$03,$08,$91,$00,$05,$02
 .db $00,$0C,$00,$00,$01,$04,$91,$00
 .db $07,$04,$00,$01,$00,$00,$C0,$91
 .db $00,$06,$06,$00,$00,$82,$91,$00
 .db $08,$01,$00,$01,$00,$01,$91,$00
 .db $06,$30,$91,$00,$03,$E4,$01,$91
 .db $00,$06,$08,$08,$01,$02,$20,$00
 .db $80,$00,$04,$91,$00,$03,$0C,$0A
 .db $00,$00,$C0,$91,$00,$07,$09,$C8
 .db $00,$01,$E0,$91,$00,$07,$83,$30
 .db $91,$00,$0A,$C0,$91,$00,$03,$01
 .db $91,$00,$06,$40,$00,$00,$04,$00
 .db $C0,$40,$40,$91,$00,$03,$07,$41
 .db $80,$91,$00,$09,$01,$01,$91,$00
 .db $05,$20,$00,$30,$91,$00,$03,$07
 .db $91,$00,$03,$10,$00,$03,$80,$04
 .db $91,$00,$03,$04,$91,$00,$03,$80
 .db $01,$07,$91,$00,$09,$06,$80,$04
 .db $91,$00,$08,$08,$80,$91,$00,$13
 .db $40,$91,$00,$04,$01,$91,$00,$06
 .db $40,$91,$00,$04,$05,$91,$00,$06
 .db $48,$91,$00,$04,$16,$00,$00,$60
 .db $91,$00,$03,$C0,$91,$00,$0B,$80
 .db $91,$00,$9A
Frame16:
 .db $01
 .db $91,$00,$7D,$30,$00,$60,$91,$00
 .db $09,$E0,$00,$30,$91,$00,$08,$03
 .db $C0,$00,$30,$91,$00,$08,$03,$00
 .db $00,$08,$91,$00,$0B,$0C,$91,$00
 .db $08,$08,$00,$00,$06,$91,$00,$08
 .db $08,$00,$00,$06,$91,$00,$07,$01
 .db $10,$00,$04,$01,$91,$00,$0A,$1C
 .db $01,$91,$00,$07,$02,$80,$00,$03
 .db $C0,$91,$00,$09,$01,$E2,$00,$80
 .db $91,$00,$06,$10,$00,$00,$02,$40
 .db $91,$00,$07,$54,$00,$00,$22,$91
 .db $00,$08,$40,$00,$00,$24,$91,$00
 .db $0B,$28,$91,$00,$0A,$03,$88,$00
 .db $80,$91,$00,$06,$08,$00,$04,$09
 .db $91,$00,$08,$08,$00,$04,$91,$00
 .db $09,$38,$00,$04,$00,$0C,$91,$00
 .db $07,$0C,$00,$04,$03,$88,$91,$00
 .db $07,$10,$00,$01,$91,$00,$09,$3B
 .db $91,$00,$03,$02,$91,$00,$07,$06
 .db $00,$01,$42,$91,$00,$08,$1E,$00
 .db $00,$30,$01,$91,$00,$07,$2E,$00
 .db $60,$C8,$91,$00,$08,$06,$00,$04
 .db $D0,$91,$00,$07,$04,$10,$00,$01
 .db $E0,$91,$00,$07,$08,$88,$91,$00
 .db $04,$40,$00,$40,$91,$00,$03,$1B
 .db $FC,$00,$00,$12,$00,$40,$91,$00
 .db $05,$FF,$74,$04,$00,$80,$91,$00
 .db $03,$80,$91,$00,$03,$7F,$FC,$04
 .db $01,$00,$00,$40,$00,$08,$91,$00
 .db $03,$F7,$B4,$04,$41,$91,$00,$05
 .db $80,$00,$06,$F0,$D0,$91,$00,$03
 .db $20,$91,$00,$05,$07,$C0,$40,$00
 .db $38,$03,$00,$80,$91,$00,$04,$0F
 .db $80,$20,$08,$01,$91,$00,$07,$1F
 .db $F0,$91,$00,$04,$08,$91,$00,$05
 .db $3F,$A0,$00,$06,$91,$00,$08,$3F
 .db $91,$00,$0B,$3F,$91,$00,$04,$18
 .db $91,$00,$06,$30,$04,$91,$00,$03
 .db $20,$91,$00,$06,$20,$91,$00,$12
 .db $02,$91,$00,$0F,$04,$91,$00,$13
 .db $02,$91,$00,$6F
Frame17:
 .db $01
 .db $91,$00,$7D,$08,$00,$80,$91,$00
 .db $14,$23,$91,$00,$07,$01,$91,$00
 .db $03,$33,$00,$00,$10,$91,$00,$08
 .db $88,$91,$00,$16,$02,$20,$91,$00
 .db $0A,$0B,$40,$00,$02,$91,$00,$09
 .db $20,$91,$00,$0A,$0A,$80,$91,$00
 .db $0A,$01,$00,$00,$10,$91,$00,$05
 .db $06,$00,$00,$2C,$00,$00,$02,$00
 .db $40,$91,$00,$03,$01,$00,$00,$68
 .db $00,$00,$02,$00,$40,$91,$00,$06
 .db $3C,$91,$00,$17,$08,$91,$00,$0D
 .db $04,$0C,$91,$00,$08,$40,$00,$00
 .db $04,$91,$00,$0B,$08,$91,$00,$06
 .db $02,$91,$00,$04,$02,$0C,$91,$00
 .db $0C,$C0,$91,$00,$04,$01,$00,$30
 .db $91,$00,$0A,$08,$91,$00,$0A,$40
 .db $F0,$91,$00,$04,$01,$91,$00,$04
 .db $01,$C0,$8E,$A0,$01,$40,$00,$00
 .db $80,$00,$26,$91,$00,$05,$01,$0C
 .db $10,$91,$00,$03,$80,$91,$00,$03
 .db $06,$00,$02,$08,$20,$91,$00,$07
 .db $0A,$08,$00,$00,$20,$91,$00,$03
 .db $40,$91,$00,$03,$0A,$80,$00,$00
 .db $10,$00,$20,$00,$C0,$00,$00,$40
 .db $00,$80,$05,$91,$00,$03,$20,$00
 .db $80,$00,$07,$40,$91,$00,$05,$C0
 .db $00,$00,$48,$00,$01,$91,$00,$04
 .db $10,$00,$00,$40,$91,$00,$06,$80
 .db $00,$10,$91,$00,$07,$40,$00,$00
 .db $01,$83,$00,$C0,$91,$00,$06,$60
 .db $00,$0C,$01,$91,$00,$08,$40,$00
 .db $05,$00,$00,$0C,$91,$00,$06,$20
 .db $00,$04,$91,$00,$0D,$01,$00,$08
 .db $18,$91,$00,$08,$0D,$91,$00,$07
 .db $04,$91,$00,$03,$06,$00,$00,$20
 .db $91,$00,$22,$01,$91,$00,$03,$04
 .db $91,$00,$83
Frame18:
 .db $01
 .db $91,$00,$7D,$06,$07,$91,$00,$0A
 .db $18,$01,$C0,$91,$00,$08,$20,$00
 .db $00,$C0,$91,$00,$08,$30,$00,$00
 .db $20,$91,$00,$08,$0C,$00,$00,$10
 .db $91,$00,$04,$02,$91,$00,$03,$08
 .db $00,$00,$18,$91,$00,$08,$08,$00
 .db $00,$08,$91,$00,$08,$90,$00,$01
 .db $8E,$91,$00,$08,$30,$00,$0F,$82
 .db $91,$00,$08,$20,$00,$01,$03,$91
 .db $00,$08,$E0,$00,$03,$03,$91,$00
 .db $04,$06,$00,$00,$3D,$C0,$00,$10
 .db $03,$91,$00,$04,$07,$00,$00,$3F
 .db $80,$00,$1C,$03,$91,$00,$07,$1A
 .db $00,$00,$66,$03,$80,$91,$00,$06
 .db $04,$00,$0D,$58,$07,$80,$91,$00
 .db $06,$0C,$00,$04,$12,$1F,$80,$91
 .db $00,$04,$C0,$00,$0C,$00,$03,$F3
 .db $3F,$91,$00,$06,$1E,$CC,$00,$02
 .db $BB,$BE,$91,$00,$05,$60,$20,$74
 .db $00,$0C,$38,$9C,$91,$00,$05,$63
 .db $A4,$78,$00,$0C,$4E,$04,$91,$00
 .db $05,$01,$E4,$58,$00,$04,$CC,$02
 .db $C0,$91,$00,$04,$01,$43,$F0,$00
 .db $06,$04,$03,$80,$91,$00,$05,$7F
 .db $F8,$00,$02,$C0,$01,$80,$91,$00
 .db $04,$47,$3F,$F8,$00,$02,$F0,$01
 .db $E0,$91,$00,$04,$0F,$81,$68,$00
 .db $E1,$78,$00,$60,$00,$A2,$00,$00
 .db $1F,$FF,$F0,$03,$13,$30,$00,$70
 .db $00,$80,$00,$00,$1F,$F9,$C8,$02
 .db $07,$A0,$00,$78,$00,$80,$00,$00
 .db $5F,$F1,$B0,$00,$0C,$40,$00,$38
 .db $00,$40,$00,$00,$1F,$F1,$7C,$04
 .db $00,$0C,$00,$1E,$00,$C0,$00,$00
 .db $5E,$7F,$F4,$01,$00,$3F,$80,$1F
 .db $00,$84,$00,$07,$5C,$3F,$FC,$04
 .db $00,$FF,$00,$3E,$E0,$C8,$00,$01
 .db $0F,$37,$B4,$00,$57,$EF,$C0,$3E
 .db $C5,$91,$00,$03,$0F,$30,$50,$00
 .db $33,$0F,$C0,$7A,$91,$00,$04,$41
 .db $00,$40,$00,$3A,$FA,$00,$7E,$91
 .db $00,$05,$18,$20,$05,$9E,$30,$00
 .db $FE,$91,$00,$05,$40,$00,$01,$80
 .db $00,$04,$7C,$91,$00,$05,$44,$00
 .db $02,$00,$04,$00,$1C,$91,$00,$09
 .db $0A,$00,$01,$98,$91,$00,$03,$01
 .db $91,$00,$04,$22,$00,$08,$91,$00
 .db $04,$08,$91,$00,$04,$06,$00,$08
 .db $20,$91,$00,$0A,$0C,$91,$00,$0B
 .db $06,$1E,$00,$00,$07,$91,$00,$07
 .db $02,$FF,$FF,$C0,$04,$91,$00,$07
 .db $03,$FF,$FF,$C0,$91,$00,$08,$03
 .db $FF,$FF,$C0,$91,$00,$6C
Frame19:
 .db $01
 .db $91,$00,$7E,$18,$91,$00,$0A,$08
 .db $02,$91,$00,$0B,$01,$91,$00,$0C
 .db $40,$91,$00,$17,$10,$91,$00,$04
 .db $02,$91,$00,$03,$08,$91,$00,$07
 .db $02,$91,$00,$03,$80,$00,$00,$08
 .db $91,$00,$0A,$0C,$04,$91,$00,$07
 .db $01,$00,$00,$12,$91,$00,$04,$40
 .db $91,$00,$04,$A0,$00,$31,$91,$00
 .db $03,$01,$91,$00,$05,$40,$00,$30
 .db $91,$00,$04,$80,$91,$00,$12,$76
 .db $91,$00,$09,$80,$09,$74,$08,$91
 .db $00,$07,$04,$00,$00,$12,$91,$00
 .db $08,$04,$00,$08,$30,$08,$91,$00
 .db $06,$04,$04,$00,$09,$30,$91,$00
 .db $08,$EC,$00,$00,$33,$20,$91,$00
 .db $07,$68,$00,$00,$51,$08,$91,$00
 .db $05,$30,$C4,$80,$00,$08,$02,$01
 .db $80,$91,$00,$04,$10,$03,$80,$00
 .db $00,$CA,$91,$00,$06,$10,$47,$00
 .db $00,$05,$8C,$00,$40,$91,$00,$04
 .db $61,$91,$00,$03,$02,$04,$00,$10
 .db $91,$00,$03,$01,$30,$91,$00,$03
 .db $01,$88,$00,$10,$00,$80,$80,$01
 .db $60,$00,$00,$01,$20,$70,$00,$08
 .db $01,$91,$00,$03,$E0,$00,$00,$03
 .db $70,$D0,$00,$00,$01,$91,$00,$03
 .db $A0,$91,$00,$03,$05,$80,$91,$00
 .db $05,$01,$E0,$91,$00,$04,$C0,$00
 .db $06,$91,$00,$03,$01,$C1,$80,$00
 .db $04,$00,$C0,$00,$01,$01,$91,$00
 .db $03,$13,$C0,$00,$04,$00,$40,$00
 .db $02,$81,$80,$00,$00,$48,$C0,$00
 .db $04,$05,$70,$00,$01,$91,$00,$04
 .db $0E,$C0,$00,$00,$03,$30,$80,$06
 .db $91,$00,$05,$C0,$00,$00,$01,$06
 .db $00,$02,$91,$00,$05,$38,$00,$08
 .db $45,$40,$00,$62,$91,$00,$05,$10
 .db $00,$0E,$91,$00,$03,$24,$91,$00
 .db $05,$04,$91,$00,$03,$08,$00,$04
 .db $91,$00,$04,$01,$91,$00,$04,$08
 .db $00,$0A,$80,$91,$00,$08,$30,$00
 .db $19,$91,$00,$0C,$40,$91,$00,$0C
 .db $01,$C0,$07,$80,$91,$00,$06,$08
 .db $7E,$C0,$91,$00,$91
Frame20:
 .db $01
 .db $91,$00,$7D,$02,$60,$91,$00,$0A
 .db $10,$0C,$91,$00,$09,$03,$00,$0E
 .db $91,$00,$05,$01,$91,$00,$03,$03
 .db $00,$00,$40,$91,$00,$08,$80,$91
 .db $00,$07,$02,$91,$00,$0B,$02,$00
 .db $00,$02,$20,$91,$00,$07,$02,$00
 .db $00,$0B,$40,$91,$00,$0B,$10,$91
 .db $00,$0A,$0B,$00,$00,$10,$04,$91
 .db $00,$03,$40,$91,$00,$04,$80,$00
 .db $00,$04,$00,$00,$01,$91,$00,$04
 .db $40,$40,$91,$00,$03,$C0,$91,$00
 .db $06,$04,$40,$00,$9B,$00,$C0,$91
 .db $00,$06,$62,$00,$00,$08,$91,$00
 .db $0A,$08,$23,$91,$00,$08,$04,$00
 .db $08,$28,$91,$00,$08,$08,$91,$00
 .db $03,$08,$91,$00,$06,$04,$91,$00
 .db $0A,$20,$20,$F0,$00,$00,$D4,$91
 .db $00,$06,$20,$00,$E0,$00,$00,$20
 .db $10,$91,$00,$05,$30,$80,$10,$91
 .db $00,$09,$10,$40,$40,$00,$08,$30
 .db $91,$00,$06,$10,$F8,$80,$00,$00
 .db $0C,$00,$20,$91,$00,$04,$06,$7C
 .db $00,$00,$06,$00,$00,$10,$91,$00
 .db $04,$81,$91,$00,$04,$08,$00,$10
 .db $00,$5C,$80,$03,$80,$00,$00,$01
 .db $20,$88,$00,$18,$91,$00,$07,$01
 .db $73,$B0,$00,$18,$91,$00,$07,$02
 .db $09,$80,$00,$08,$91,$00,$03,$01
 .db $B0,$91,$00,$06,$08,$91,$00,$03
 .db $01,$D0,$91,$00,$06,$0E,$00,$04
 .db $00,$00,$08,$91,$00,$06,$0C,$91
 .db $00,$08,$63,$80,$91,$00,$06,$02
 .db $91,$00,$03,$01,$C0,$91,$00,$06
 .db $06,$91,$00,$03,$01,$00,$00,$C4
 .db $91,$00,$04,$03,$C0,$91,$00,$03
 .db $80,$00,$04,$91,$00,$05,$E0,$00
 .db $02,$91,$00,$09,$40,$91,$00,$05
 .db $28,$91,$00,$04,$01,$91,$00,$04
 .db $18,$00,$12,$91,$00,$18,$40,$91
 .db $00,$17,$64,$BF,$C0,$91,$00,$90
Frame21:
 .db $01
 .db $91,$00,$7D,$03,$80,$91,$00,$0A
 .db $1F,$F0,$91,$00,$05,$01,$F0,$01
 .db $40,$00,$38,$0E,$91,$00,$0A,$C0
 .db $00,$40,$91,$00,$08,$03,$00,$00
 .db $20,$91,$00,$04,$04,$91,$00,$03
 .db $04,$00,$00,$10,$91,$00,$08,$0E
 .db $00,$00,$10,$91,$00,$04,$04,$91
 .db $00,$03,$20,$00,$00,$08,$91,$00
 .db $08,$10,$00,$00,$08,$91,$00,$0A
 .db $0C,$91,$00,$04,$40,$91,$00,$03
 .db $02,$20,$00,$C2,$91,$00,$08,$02
 .db $00,$00,$C1,$04,$00,$00,$01,$00
 .db $07,$91,$00,$04,$03,$64,$0C,$91
 .db $00,$04,$01,$91,$00,$05,$17,$0C
 .db $91,$00,$08,$80,$0C,$0F,$91,$00
 .db $06,$20,$00,$04,$00,$08,$48,$91
 .db $00,$06,$60,$00,$08,$00,$08,$50
 .db $91,$00,$06,$50,$00,$78,$00,$08
 .db $00,$40,$91,$00,$05,$10,$01,$50
 .db $00,$00,$D8,$40,$91,$00,$07,$E0
 .db $00,$00,$02,$20,$91,$00,$06,$21
 .db $10,$00,$00,$02,$1F,$80,$91,$00
 .db $05,$A7,$C0,$00,$08,$62,$07,$80
 .db $91,$00,$05,$A7,$80,$00,$08,$8C
 .db $07,$E0,$91,$00,$04,$60,$9C,$00
 .db $00,$04,$00,$07,$E0,$00,$00,$40
 .db $00,$7E,$A0,$00,$00,$04,$00,$07
 .db $E0,$91,$00,$03,$02,$FF,$E0,$00
 .db $01,$63,$08,$0F,$E0,$01,$91,$00
 .db $03,$FF,$C0,$00,$00,$01,$00,$0F
 .db $E0,$01,$91,$00,$03,$FF,$C0,$00
 .db $00,$01,$80,$0F,$F0,$91,$00,$04
 .db $48,$80,$91,$00,$04,$3F,$F0,$00
 .db $06,$00,$00,$78,$A0,$00,$04,$00
 .db $80,$3F,$F0,$91,$00,$04,$70,$80
 .db $91,$00,$03,$01,$BF,$F0,$61,$91
 .db $00,$03,$78,$00,$00,$04,$61,$FF
 .db $BF,$F8,$00,$03,$00,$00,$3C,$91
 .db $00,$03,$31,$F2,$3F,$F8,$91,$00
 .db $04,$78,$00,$00,$08,$01,$80,$01
 .db $38,$91,$00,$04,$3C,$00,$00,$19
 .db $25,$00,$00,$98,$91,$00,$04,$1F
 .db $00,$00,$09,$91,$00,$03,$58,$91
 .db $00,$04,$0F,$80,$91,$00,$03,$08
 .db $00,$10,$91,$00,$04,$0F,$91,$00
 .db $04,$38,$00,$01,$91,$00,$04,$01
 .db $91,$00,$06,$01,$91,$00,$03,$07
 .db $F0,$91,$00,$0A,$07,$E0,$91,$00
 .db $06,$01,$FF,$FE,$91,$00,$09,$0F
 .db $FB,$80,$91,$00,$91
Frame22:
 .db $01
 .db $91,$00,$7D,$5F,$FF,$80,$91,$00
 .db $07,$02,$01,$FF,$FF,$E0,$91,$00
 .db $05,$34,$02,$A2,$01,$F8,$01,$F0
 .db $91,$00,$04,$03,$40,$00,$00,$03
 .db $C0,$00,$78,$91,$00,$04,$03,$91
 .db $00,$03,$07,$00,$00,$3C,$91,$00
 .db $04,$06,$91,$00,$03,$04,$00,$03
 .db $1E,$91,$00,$04,$02,$91,$00,$03
 .db $06,$00,$4F,$1E,$91,$00,$04,$06
 .db $91,$00,$05,$18,$0E,$91,$00,$07
 .db $1F,$F0,$02,$1C,$0F,$91,$00,$05
 .db $C0,$00,$3F,$E0,$00,$38,$07,$80
 .db $00,$00,$80,$00,$C0,$00,$3F,$E0
 .db $00,$CE,$07,$80,$00,$02,$00,$00
 .db $C0,$00,$FF,$C0,$00,$FE,$07,$80
 .db $00,$03,$C0,$00,$00,$01,$FF,$C0
 .db $07,$CF,$0F,$80,$00,$00,$80,$00
 .db $00,$01,$FC,$00,$07,$ED,$0F,$91
 .db $00,$03,$80,$00,$00,$01,$FC,$00
 .db $03,$C2,$0C,$91,$00,$05,$20,$03
 .db $F8,$00,$03,$8B,$91,$00,$06,$20
 .db $07,$F8,$00,$03,$E2,$20,$91,$00
 .db $05,$10,$0F,$80,$00,$01,$70,$60
 .db $91,$00,$05,$10,$1E,$00,$00,$0F
 .db $F0,$60,$91,$00,$09,$0F,$78,$20
 .db $91,$00,$06,$EE,$00,$00,$0F,$8C
 .db $91,$00,$07,$08,$00,$00,$07,$AC
 .db $38,$91,$00,$09,$0F,$8C,$F8,$91
 .db $00,$05,$10,$91,$00,$03,$02,$C5
 .db $F8,$91,$00,$05,$70,$50,$00,$00
 .db $87,$C0,$38,$00,$01,$40,$40,$00
 .db $00,$18,$00,$01,$8C,$CF,$10,$00
 .db $00,$20,$91,$00,$03,$3C,$00,$01
 .db $FD,$CF,$B0,$91,$00,$06,$3E,$00
 .db $03,$C1,$FF,$90,$91,$00,$03,$40
 .db $00,$07,$3F,$D2,$03,$80,$FF,$86
 .db $00,$00,$06,$40,$00,$77,$5F,$C3
 .db $E4,$00,$7F,$80,$00,$1A,$04,$40
 .db $00,$77,$3F,$FF,$EC,$00,$7E,$00
 .db $01,$C6,$91,$00,$03,$7F,$F3,$FF
 .db $E4,$E0,$0C,$00,$04,$06,$03,$00
 .db $00,$4F,$FE,$FF,$F8,$80,$52,$B8
 .db $91,$00,$05,$7F,$EE,$FF,$D2,$3F
 .db $80,$00,$C0,$00,$00,$40,$00,$3F
 .db $ED,$FB,$D1,$7C,$00,$00,$FF,$FC
 .db $91,$00,$03,$1F,$F1,$12,$0E,$00
 .db $04,$00,$7B,$9F,$FF,$80,$00,$0F
 .db $C0,$91,$00,$03,$1C,$00,$38,$3F
 .db $FF,$C0,$00,$0F,$91,$00,$04,$10
 .db $00,$1F,$FF,$FF,$C0,$00,$03,$91
 .db $00,$06,$1F,$FF,$FF,$C0,$91,$00
 .db $08,$0F,$FF,$FF,$C0,$91,$00,$08
 .db $0E,$91,$00,$9F
Frame23:
 .db $01
 .db $91,$00,$7D,$A0,$00,$40,$91,$00
 .db $07,$02,$02,$91,$00,$08,$34,$02
 .db $A2,$06,$00,$00,$08,$91,$00,$05
 .db $40,$00,$00,$0C,$00,$00,$04,$91
 .db $00,$04,$03,$91,$00,$03,$08,$00
 .db $00,$02,$91,$00,$08,$08,$00,$14
 .db $91,$00,$09,$08,$00,$40,$91,$00
 .db $05,$02,$91,$00,$03,$10,$00,$04
 .db $01,$C0,$91,$00,$06,$41,$91,$00
 .db $04,$C0,$91,$00,$04,$C0,$00,$C0
 .db $00,$00,$08,$00,$40,$91,$00,$04
 .db $C0,$00,$C0,$00,$04,$12,$00,$40
 .db $91,$00,$04,$C0,$07,$00,$00,$04
 .db $91,$00,$08,$06,$91,$00,$03,$80
 .db $00,$80,$00,$01,$40,$00,$00,$06
 .db $91,$00,$03,$18,$01,$91,$00,$03
 .db $80,$00,$00,$06,$91,$00,$03,$30
 .db $91,$00,$07,$04,$91,$00,$03,$5D
 .db $10,$91,$00,$05,$10,$08,$91,$00
 .db $04,$10,$91,$00,$05,$10,$10,$00
 .db $00,$01,$00,$10,$91,$00,$06,$20
 .db $91,$00,$03,$80,$10,$91,$00,$0A
 .db $84,$10,$91,$00,$06,$10,$91,$00
 .db $0B,$10,$91,$00,$03,$10,$91,$00
 .db $07,$20,$91,$00,$0A,$10,$20,$91
 .db $00,$03,$20,$91,$00,$06,$70,$10
 .db $00,$01,$A3,$91,$00,$03,$01,$40
 .db $40,$00,$00,$18,$00,$02,$0E,$10
 .db $91,$00,$03,$20,$91,$00,$03,$0C
 .db $00,$19,$0C,$10,$91,$00,$07,$0E
 .db $00,$00,$3C,$91,$00,$08,$41,$D3
 .db $E0,$60,$00,$06,$91,$00,$07,$20
 .db $67,$C0,$91,$00,$03,$02,$04,$91
 .db $00,$03,$40,$00,$0C,$C0,$00,$C0
 .db $00,$80,$91,$00,$03,$40,$0C,$00
 .db $28,$00,$0C,$C0,$06,$91,$00,$04
 .db $70,$00,$00,$30,$08,$48,$18,$91
 .db $00,$06,$11,$00,$02,$91,$00,$09
 .db $10,$04,$08,$91,$00,$03,$20,$91
 .db $00,$06,$0E,$06,$91,$00,$04,$A0
 .db $00,$40,$91,$00,$06,$08,$00,$07
 .db $C0,$91,$00,$0F,$1C,$91,$00,$BE
Frame24:
 .db $01
 .db $91,$00,$7D,$80,$00,$38,$91,$00
 .db $04,$02,$91,$00,$03,$03,$00,$00
 .db $1C,$91,$00,$04,$03,$40,$00,$00
 .db $06,$00,$00,$04,$91,$00,$04,$04
 .db $60,$00,$00,$08,$00,$00,$02,$91
 .db $00,$04,$01,$91,$00,$03,$08,$00
 .db $02,$91,$00,$05,$03,$91,$00,$03
 .db $20,$00,$1F,$01,$91,$00,$04,$02
 .db $91,$00,$05,$03,$01,$91,$00,$0A
 .db $18,$00,$40,$91,$00,$03,$01,$00
 .db $00,$5E,$F0,$02,$14,$00,$40,$91
 .db $00,$06,$FF,$E0,$00,$30,$00,$C0
 .db $00,$00,$C0,$01,$00,$00,$FF,$C0
 .db $04,$20,$00,$C0,$00,$02,$00,$02
 .db $00,$07,$FF,$00,$05,$DB,$00,$80
 .db $00,$02,$00,$06,$40,$07,$FD,$00
 .db $07,$43,$01,$91,$00,$04,$01,$80
 .db $07,$30,$00,$04,$11,$0E,$91,$00
 .db $06,$07,$F0,$00,$04,$E1,$1C,$91
 .db $00,$06,$01,$80,$00,$03,$04,$10
 .db $91,$00,$05,$10,$0F,$C0,$00,$03
 .db $40,$10,$91,$00,$05,$18,$1F,$80
 .db $00,$00,$C0,$0C,$91,$00,$06,$3F
 .db $80,$00,$00,$C0,$0F,$80,$91,$00
 .db $05,$10,$91,$00,$04,$0F,$E0,$91
 .db $00,$05,$B0,$91,$00,$03,$50,$1F
 .db $F0,$91,$00,$04,$04,$A8,$00,$00
 .db $30,$20,$3F,$F0,$91,$00,$04,$04
 .db $28,$00,$00,$3E,$E0,$FF,$E0,$91
 .db $00,$04,$04,$30,$00,$00,$3F,$21
 .db $FF,$F0,$00,$00,$C0,$00,$0C,$00
 .db $00,$01,$5F,$00,$3F,$F0,$00,$00
 .db $80,$00,$00,$20,$00,$03,$FE,$23
 .db $1F,$F0,$00,$02,$91,$00,$05,$19
 .db $FC,$21,$BF,$F0,$00,$02,$91,$00
 .db $03,$10,$00,$00,$FC,$60,$9F,$F0
 .db $00,$00,$C0,$00,$00,$1E,$01,$E0
 .db $2C,$C3,$BF,$F0,$1E,$00,$C0,$00
 .db $30,$1F,$E3,$80,$4C,$03,$BF,$F8
 .db $09,$E0,$40,$00,$10,$0F,$FF,$E3
 .db $48,$03,$7F,$F9,$46,$01,$00,$00
 .db $20,$07,$FF,$CF,$4E,$27,$7F,$FB
 .db $E7,$FF,$C0,$07,$FF,$FE,$FF,$CF
 .db $77,$48,$1F,$FF,$7F,$FF,$C0,$07
 .db $F7,$FF,$FF,$DE,$00,$00,$01,$3F
 .db $2F,$C1,$80,$07,$FF,$FD,$FF,$CE
 .db $91,$00,$03,$29,$FB,$BC,$00,$07
 .db $FF,$F1,$1C,$0E,$00,$0C,$00,$04
 .db $E9,$43,$C0,$01,$FF,$C0,$91,$00
 .db $03,$20,$00,$01,$F8,$0C,$00,$07
 .db $FF,$91,$00,$04,$30,$00,$01,$80
 .db $00,$00,$07,$E0,$91,$00,$07,$40
 .db $91,$00,$0A,$07,$91,$00,$0B,$04
 .db $91,$00,$9F
Frame25:
 .db $01
 .db $91,$00,$7F,$08,$91,$00,$0B,$04
 .db $91,$00,$0B,$04,$91,$00,$16,$02
 .db $91,$00,$0C,$01,$91,$00,$08,$10
 .db $00,$08,$91,$00,$11,$01,$91,$00
 .db $03,$10,$00,$38,$91,$00,$09,$10
 .db $02,$00,$00,$80,$91,$00,$03,$01
 .db $91,$00,$03,$20,$02,$08,$00,$80
 .db $91,$00,$03,$03,$91,$00,$03,$80
 .db $03,$E1,$91,$00,$08,$03,$91,$00
 .db $0B,$8C,$91,$00,$03,$08,$91,$00
 .db $07,$08,$00,$02,$10,$10,$91,$00
 .db $07,$10,$91,$00,$0B,$40,$00,$00
 .db $02,$10,$91,$00,$07,$80,$91,$00
 .db $03,$0C,$80,$91,$00,$09,$40,$00
 .db $40,$91,$00,$05,$01,$91,$00,$0B
 .db $5D,$91,$00,$0B,$06,$91,$00,$05
 .db $10,$91,$00,$05,$10,$91,$00,$08
 .db $40,$91,$00,$05,$40,$00,$00,$10
 .db $91,$00,$11,$20,$00,$00,$80,$91
 .db $00,$08,$30,$00,$00,$80,$02,$00
 .db $08,$91,$00,$08,$8F,$03,$00,$08
 .db $91,$00,$05,$20,$00,$00,$43,$00
 .db $00,$09,$98,$08,$91,$00,$03,$20
 .db $00,$00,$03,$08,$91,$00,$04,$80
 .db $00,$00,$70,$00,$00,$04,$1C,$91
 .db $00,$03,$01,$00,$07,$DF,$F8,$00
 .db $00,$08,$18,$91,$00,$0A,$08,$20
 .db $91,$00,$06,$08,$91,$00,$03,$40
 .db $91,$00,$0E,$08,$00,$04,$91,$00
 .db $0B,$07,$80,$06,$91,$00,$05,$10
 .db $91,$00,$19,$02,$91,$00,$17,$01
 .db $91,$00,$9F
Frame26:
 .db $01
 .db $91,$00,$78,$06,$91,$00,$04,$7F
 .db $FF,$F0,$91,$00,$09,$EF,$F0,$F8
 .db $91,$00,$05,$80,$00,$00,$01,$EC
 .db $00,$08,$91,$00,$04,$06,$60,$00
 .db $00,$07,$EC,$00,$02,$91,$00,$04
 .db $01,$91,$00,$03,$07,$F8,$91,$00
 .db $06,$01,$80,$00,$00,$2F,$80,$08
 .db $91,$00,$06,$80,$00,$00,$1F,$00
 .db $04,$01,$91,$00,$05,$80,$00,$00
 .db $18,$00,$04,$01,$80,$91,$00,$04
 .db $80,$00,$00,$18,$00,$30,$00,$80
 .db $91,$00,$04,$80,$00,$00,$08,$02
 .db $91,$00,$05,$C0,$91,$00,$04,$18
 .db $02,$09,$C0,$91,$00,$07,$60,$90
 .db $02,$3A,$C0,$C0,$00,$00,$40,$00
 .db $C0,$00,$01,$A0,$03,$F3,$E1,$C0
 .db $00,$02,$40,$00,$80,$00,$43,$C4
 .db $03,$F3,$07,$C0,$00,$01,$C0,$91
 .db $00,$03,$44,$10,$01,$33,$8F,$C0
 .db $91,$00,$06,$18,$00,$00,$82,$9F
 .db $C0,$91,$00,$06,$60,$00,$00,$C1
 .db $0F,$91,$00,$05,$08,$00,$C0,$00
 .db $00,$D9,$6F,$80,$91,$00,$05,$10
 .db $40,$00,$00,$1F,$E0,$40,$91,$00
 .db $05,$17,$91,$00,$03,$1F,$E0,$60
 .db $91,$00,$05,$1A,$E0,$00,$00,$1C
 .db $20,$70,$91,$00,$04,$04,$12,$00
 .db $00,$30,$08,$20,$60,$00,$01,$40
 .db $00,$04,$18,$80,$00,$3E,$60,$91
 .db $00,$04,$C0,$00,$19,$40,$00,$00
 .db $7B,$C8,$91,$00,$03,$01,$80,$00
 .db $0C,$1E,$00,$00,$73,$A0,$00,$0E
 .db $04,$09,$80,$00,$7F,$A0,$00,$00
 .db $61,$CF,$20,$10,$84,$03,$00,$07
 .db $FF,$CC,$00,$00,$60,$04,$60,$38
 .db $1F,$03,$00,$07,$FF,$E8,$00,$00
 .db $4F,$63,$E0,$78,$67,$71,$80,$07
 .db $FF,$C0,$00,$00,$4F,$C2,$00,$39
 .db $47,$F7,$40,$00,$4F,$C0,$00,$00
 .db $4B,$0C,$00,$39,$90,$67,$80,$07
 .db $6F,$80,$00,$00,$48,$00,$00,$7B
 .db $03,$00,$C0,$91,$00,$05,$02,$30
 .db $00,$7D,$FF,$FF,$C0,$91,$00,$05
 .db $40,$00,$00,$33,$7F,$07,$C0,$91
 .db $00,$04,$02,$40,$00,$00,$37,$4F
 .db $41,$C0,$91,$00,$06,$08,$00,$7C
 .db $54,$78,$91,$00,$07,$30,$00,$14
 .db $29,$CB,$40,$91,$00,$06,$20,$00
 .db $06,$E8,$0F,$91,$00,$09,$01,$B0
 .db $00,$80,$91,$00,$08,$02,$60,$91
 .db $00,$0A,$07,$91,$00,$0B,$05,$91
 .db $00,$9F
Frame27:
 .db $01
 .db $91,$00,$89,$10,$0F,$91,$00,$0A
 .db $10,$C7,$F0,$91,$00,$09,$10,$80
 .db $0C,$91,$00,$09,$12,$00,$06,$91
 .db $00,$09,$7C,$00,$02,$91,$00,$09
 .db $F0,$00,$02,$91,$00,$08,$07,$C0
 .db $91,$00,$0A,$06,$91,$00,$0B,$04
 .db $91,$00,$03,$80,$91,$00,$07,$06
 .db $00,$01,$00,$80,$00,$00,$40,$91
 .db $00,$03,$60,$EE,$00,$00,$20,$C0
 .db $00,$00,$80,$91,$00,$04,$5E,$00
 .db $00,$80,$40,$00,$03,$91,$00,$04
 .db $47,$D8,$91,$00,$03,$40,$00,$02
 .db $40,$91,$00,$03,$54,$0C,$00,$00
 .db $40,$40,$91,$00,$06,$08,$02,$00
 .db $20,$80,$40,$91,$00,$06,$60,$00
 .db $00,$03,$00,$80,$91,$00,$05,$07
 .db $40,$00,$00,$27,$00,$80,$91,$00
 .db $05,$08,$40,$00,$00,$60,$40,$80
 .db $91,$00,$05,$2E,$91,$00,$03,$20
 .db $20,$80,$91,$00,$05,$06,$E0,$00
 .db $00,$38,$E0,$80,$91,$00,$04,$78
 .db $1C,$91,$00,$03,$28,$60,$80,$91
 .db $00,$04,$40,$0C,$80,$91,$00,$04
 .db $20,$91,$00,$04,$1C,$4E,$00,$00
 .db $04,$40,$00,$3F,$91,$00,$05,$84
 .db $00,$00,$02,$21,$00,$3E,$82,$02
 .db $00,$00,$7E,$B8,$00,$00,$01,$02
 .db $E0,$20,$8B,$FF,$00,$07,$FF,$F0
 .db $00,$00,$20,$01,$A0,$40,$39,$2E
 .db $00,$07,$E7,$08,$91,$00,$04,$20
 .db $00,$A6,$F2,$C0,$07,$C0,$91,$00
 .db $07,$41,$0C,$91,$00,$06,$04,$04
 .db $00,$00,$81,$90,$00,$07,$80,$91
 .db $00,$05,$03,$80,$03,$91,$00,$09
 .db $01,$80,$91,$00,$09,$80,$00,$48
 .db $00,$10,$91,$00,$05,$02,$91,$00
 .db $03,$CC,$91,$00,$0B,$02,$16,$C0
 .db $91,$00,$09,$11,$B0,$89,$91,$00
 .db $09,$07,$20,$03,$91,$00,$0A,$10
 .db $00,$80,$91,$00,$C0
Frame28:
 .db $01
 .db $91,$00,$78,$01,$C0,$91,$00,$0D
 .db $02,$00,$33,$30,$91,$00,$06,$74
 .db $02,$A2,$01,$B0,$00,$80,$91,$00
 .db $08,$01,$30,$40,$30,$91,$00,$09
 .db $15,$00,$08,$91,$00,$0B,$04,$91
 .db $00,$09,$08,$91,$00,$0B,$20,$91
 .db $00,$07,$80,$00,$00,$01,$80,$00
 .db $01,$91,$00,$08,$02,$91,$00,$08
 .db $80,$00,$82,$91,$00,$03,$C0,$91
 .db $00,$03,$C0,$01,$80,$01,$E2,$E2
 .db $00,$00,$20,$91,$00,$04,$01,$20
 .db $00,$80,$02,$91,$00,$03,$80,$91
 .db $00,$04,$50,$0E,$C4,$20,$91,$00
 .db $03,$80,$91,$00,$05,$0E,$40,$00
 .db $00,$02,$C0,$91,$00,$03,$80,$00
 .db $00,$08,$20,$02,$00,$22,$80,$91
 .db $00,$0A,$41,$91,$00,$07,$04,$80
 .db $00,$00,$05,$60,$91,$00,$05,$04
 .db $00,$80,$00,$00,$40,$E0,$91,$00
 .db $0A,$20,$40,$91,$00,$0A,$09,$C0
 .db $91,$00,$05,$18,$0E,$91,$00,$03
 .db $10,$C0,$00,$00,$01,$80,$00,$44
 .db $13,$91,$00,$03,$10,$80,$07,$91
 .db $00,$04,$11,$06,$00,$00,$04,$C8
 .db $00,$1F,$B8,$91,$00,$03,$01,$02
 .db $00,$00,$0A,$61,$00,$02,$84,$F4
 .db $91,$00,$06,$23,$11,$C0,$20,$2E
 .db $3D,$C0,$00,$17,$91,$00,$03,$01
 .db $C6,$00,$80,$67,$CF,$C0,$00,$07
 .db $91,$00,$03,$41,$C0,$00,$80,$A0
 .db $83,$C0,$00,$40,$91,$00,$03,$01
 .db $80,$00,$C1,$41,$33,$C0,$91,$00
 .db $08,$C0,$15,$56,$C0,$07,$91,$00
 .db $07,$02,$15,$40,$C0,$91,$00,$05
 .db $48,$10,$01,$83,$97,$60,$91,$00
 .db $06,$40,$00,$00,$03,$7F,$28,$91
 .db $00,$09,$EA,$9D,$00,$80,$91,$00
 .db $08,$2F,$80,$06,$91,$00,$09,$05
 .db $80,$06,$91,$00,$0B,$02,$91,$00
 .db $CD
Frame29:
 .db $01
 .db $91,$00,$78,$01,$C0,$91,$00,$0D
 .db $02,$00,$33,$30,$91,$00,$06,$74
 .db $02,$A2,$01,$B0,$00,$80,$91,$00
 .db $08,$01,$20,$00,$20,$91,$00,$35
 .db $80,$91,$00,$17,$80,$00,$82,$91
 .db $00,$07,$C0,$01,$00,$01,$E2,$80
 .db $91,$00,$07,$01,$20,$00,$80,$91
 .db $00,$09,$10,$0E,$C0,$91,$00,$04
 .db $80,$91,$00,$05,$0E,$40,$91,$00
 .db $03,$80,$91,$00,$03,$80,$00,$00
 .db $08,$91,$00,$03,$20,$91,$00,$1E
 .db $04,$18,$91,$00,$0F,$20,$60,$91
 .db $00,$06,$06,$91,$00,$03,$02,$91
 .db $00,$06,$18,$12,$91,$00,$04,$80
 .db $91,$00,$06,$01,$91,$00,$05,$71
 .db $91,$00,$04,$10,$06,$00,$00,$03
 .db $80,$00,$00,$04,$91,$00,$03,$01
 .db $84,$00,$00,$06,$52,$00,$02,$02
 .db $80,$00,$00,$01,$04,$00,$00,$03
 .db $C0,$00,$20,$01,$80,$00,$00,$14
 .db $91,$00,$03,$01,$C0,$91,$00,$0A
 .db $01,$C0,$00,$00,$10,$91,$00,$03
 .db $40,$91,$00,$03,$01,$80,$00,$01
 .db $41,$C0,$91,$00,$0A,$15,$91,$00
 .db $0A,$02,$14,$91,$00,$07,$40,$00
 .db $00,$03,$96,$10,$91,$00,$09,$03
 .db $7E,$91,$00,$0A,$EA,$9D,$00,$80
 .db $91,$00,$08,$2F,$80,$06,$91,$00
 .db $09,$05,$80,$06,$91,$00,$0A,$70
 .db $02,$91,$00,$0A,$40,$91,$00,$C2
Frame30:
 .db $01
 .db $91,$00,$84,$01,$91,$00,$04,$10
 .db $91,$00,$06,$03,$91,$00,$04,$10
 .db $B8,$91,$00,$0B,$A0,$60,$91,$00
 .db $11,$80,$91,$00,$03,$02,$91,$00
 .db $19,$02,$91,$00,$05,$80,$91,$00
 .db $03,$60,$91,$00,$1D,$40,$01,$91
 .db $00,$03,$02,$00,$01,$91,$00,$05
 .db $01,$91,$00,$06,$60,$91,$00,$07
 .db $43,$C0,$00,$00,$40,$80,$00,$00
 .db $80,$91,$00,$03,$54,$60,$00,$00
 .db $80,$80,$91,$00,$06,$22,$04,$91
 .db $00,$03,$80,$91,$00,$06,$80,$00
 .db $00,$01,$00,$80,$91,$00,$05,$02
 .db $91,$00,$03,$6B,$00,$80,$91,$00
 .db $05,$08,$91,$00,$03,$05,$91,$00
 .db $07,$1F,$91,$00,$03,$40,$20,$91
 .db $00,$06,$16,$80,$00,$00,$41,$C1
 .db $91,$00,$04,$01,$9C,$02,$91,$00
 .db $04,$80,$FF,$38,$00,$80,$00,$04
 .db $0A,$91,$00,$03,$10,$00,$B6,$00
 .db $FF,$91,$00,$03,$06,$00,$00,$07
 .db $01,$01,$40,$BC,$C6,$C0,$00,$00
 .db $9C,$00,$00,$0E,$72,$01,$00,$00
 .db $0F,$C0,$01,$37,$FC,$91,$00,$03
 .db $60,$81,$C0,$20,$7F,$C0,$03,$1A
 .db $DC,$91,$00,$03,$1E,$41,$00,$41
 .db $E0,$C0,$03,$60,$91,$00,$03,$40
 .db $00,$41,$00,$B1,$00,$00,$06,$C0
 .db $91,$00,$05,$01,$01,$E7,$01,$00
 .db $07,$80,$91,$00,$05,$07,$00,$04
 .db $80,$91,$00,$06,$40,$18,$02,$91
 .db $00,$09,$1A,$20,$01,$80,$01,$91
 .db $00,$07,$48,$00,$00,$80,$C1,$C0
 .db $91,$00,$05,$04,$91,$00,$03,$80
 .db $9B,$80,$91,$00,$09,$22,$C6,$E1
 .db $C0,$91,$00,$08,$19,$C8,$02,$91
 .db $00,$16,$40,$91,$00,$0B,$20,$91
 .db $00,$B6
Frame31:
 .db $00
 .db $91,$FF,$78,$FB,$C0,$00,$03,$FF
 .db $FC,$91,$00,$05,$3F,$F8,$00,$18
 .db $0F,$FF,$FF,$91,$00,$05,$3F,$F9
 .db $74,$14,$43,$FF,$FF,$88,$91,$00
 .db $04,$3F,$F8,$FF,$F7,$91,$FF,$03
 .db $C8,$80,$91,$00,$03,$3F,$F8,$F0
 .db $C1,$C7,$FF,$FF,$C0,$91,$00,$04
 .db $3F,$F8,$30,$00,$07,$FF,$FF,$E0
 .db $91,$00,$04,$3F,$F8,$7D,$C1,$83
 .db $FF,$FF,$F8,$91,$00,$04,$3F,$91
 .db $FF,$06,$F0,$E0,$91,$00,$03,$3F
 .db $91,$FF,$06,$F7,$E8,$00,$07,$84
 .db $3F,$91,$FF,$03,$FB,$FF,$FF,$FE
 .db $15,$30,$2B,$4C,$3F,$FB,$91,$FF
 .db $03,$7F,$FF,$FF,$CC,$E5,$C0,$6B
 .db $FF,$FB,$EF,$FF,$FE,$FF,$FF,$FD
 .db $C0,$03,$60,$03,$FF,$FB,$FF,$FF
 .db $D8,$91,$FF,$03,$C4,$00,$00,$23
 .db $FF,$FB,$FF,$FF,$E3,$77,$91,$FF
 .db $03,$F4,$00,$00,$FF,$FB,$FF,$FF
 .db $E3,$EB,$FF,$FF,$D8,$7B,$00,$C0
 .db $3F,$FB,$FF,$FF,$F8,$3F,$FF,$FF
 .db $E0,$15,$EF,$C0,$3F,$FB,$FF,$FF
 .db $FE,$1F,$FF,$FF,$F4,$02,$F0,$CF
 .db $FF,$FB,$FF,$FF,$FE,$19,$FF,$FF
 .db $FC,$00,$20,$3F,$91,$FF,$04,$FE
 .db $1F,$FF,$FF,$FC,$00,$02,$01,$BF
 .db $91,$FF,$03,$FE,$1D,$FF,$FF,$FC
 .db $01,$03,$00,$BF,$91,$FF,$03,$FE
 .db $9D,$FF,$FF,$FE,$00,$D6,$00,$3F
 .db $91,$FF,$03,$FC,$3C,$FF,$FF,$FE
 .db $02,$36,$00,$3F,$91,$FF,$03,$FD
 .db $FC,$7F,$FF,$FE,$00,$10,$00,$3F
 .db $91,$FF,$04,$FD,$7F,$FF,$FF,$08
 .db $18,$00,$3F,$91,$FF,$04,$EF,$2F
 .db $FF,$FF,$D9,$02,$02,$3F,$91,$FF
 .db $05,$03,$FF,$FF,$8F,$80,$00,$3F
 .db $91,$FF,$05,$80,$07,$FF,$F1,$80
 .db $02,$3F,$91,$FF,$05,$80,$03,$FF
 .db $FF,$88,$02,$3F,$91,$FF,$05,$80
 .db $33,$FF,$FF,$E0,$80,$91,$FF,$06
 .db $E0,$3F,$FF,$FF,$F0,$B0,$91,$FF
 .db $07,$3F,$FF,$FF,$F6,$3C,$7F,$91
 .db $FF,$09,$F7,$91,$FF,$06,$FD,$91
 .db $FF,$0B,$FD,$FF,$F7,$91,$FF,$0B
 .db $C7,$91,$FF,$0B,$9F,$91,$FF,$DD
Frame32:
 .db $01
 .db $91,$00,$78,$01,$C0,$00,$1C,$00
 .db $03,$91,$00,$06,$01,$00,$00,$10
 .db $00,$00,$80,$91,$00,$06,$44,$04
 .db $1C,$00,$00,$08,$91,$00,$0B,$08
 .db $80,$91,$00,$05,$08,$22,$28,$91
 .db $00,$09,$10,$00,$06,$00,$00,$10
 .db $91,$00,$07,$01,$83,$80,$91,$00
 .db $09,$01,$91,$00,$04,$30,$91,$00
 .db $07,$01,$00,$00,$08,$91,$00,$06
 .db $08,$00,$05,$10,$00,$03,$12,$00
 .db $10,$80,$91,$00,$04,$01,$88,$91
 .db $00,$05,$04,$00,$00,$10,$91,$00
 .db $04,$02,$38,$00,$10,$91,$00,$05
 .db $21,$91,$00,$03,$38,$01,$91,$00
 .db $06,$21,$08,$91,$00,$03,$44,$00
 .db $60,$91,$00,$04,$F9,$15,$00,$00
 .db $27,$41,$01,$91,$00,$05,$20,$80
 .db $00,$00,$1F,$96,$10,$91,$00,$05
 .db $26,$20,$00,$00,$0B,$81,$91,$00
 .db $06,$22,$A7,$80,$00,$03,$83,$80
 .db $91,$00,$05,$E6,$82,$C0,$00,$03
 .db $80,$91,$00,$06,$0E,$80,$A0,$00
 .db $03,$02,$05,$91,$00,$05,$0E,$22
 .db $F0,$00,$01,$00,$50,$91,$00,$06
 .db $02,$FE,$00,$01,$00,$32,$91,$00
 .db $07,$7F,$E0,$01,$80,$10,$91,$00
 .db $05,$0C,$03,$7F,$E0,$00,$80,$18
 .db $91,$00,$06,$10,$EE,$20,$00,$04
 .db $00,$02,$91,$00,$06,$FB,$10,$00
 .db $40,$91,$00,$06,$20,$00,$7F,$C0
 .db $91,$00,$03,$02,$91,$00,$04,$20
 .db $00,$7F,$F8,$91,$00,$03,$02,$91
 .db $00,$05,$03,$7F,$48,$91,$00,$03
 .db $07,$80,$91,$00,$04,$05,$1E,$40
 .db $91,$00,$03,$07,$91,$00,$05,$04
 .db $91,$00,$05,$03,$80,$91,$00,$05
 .db $02,$91,$00,$0A,$06,$91,$00,$0B
 .db $02,$00,$08,$91,$00,$17,$40,$91
 .db $00,$DD
Frame33:
 .db $00
 .db $91,$FF,$79,$80,$01,$91,$FF,$03
 .db $E0,$91,$00,$04,$3F,$F9,$DF,$01
 .db $F1,$FF,$FF,$E0,$91,$00,$04,$3F
 .db $F8,$F1,$83,$40,$FF,$FF,$F8,$91
 .db $00,$04,$3F,$F8,$F1,$FF,$C0,$BF
 .db $FF,$FF,$91,$00,$04,$3F,$F8,$08
 .db $40,$6E,$3F,$FF,$C3,$80,$40,$00
 .db $00,$3F,$FF,$3D,$F9,$91,$FF,$03
 .db $C0,$C0,$D8,$00,$00,$3F,$91,$FF
 .db $03,$F2,$F7,$FF,$F0,$7A,$B8,$00
 .db $00,$3F,$FB,$F7,$FD,$FB,$73,$FF
 .db $FF,$02,$CF,$0F,$F0,$BF,$FF,$F3
 .db $FF,$FC,$77,$FF,$FF,$80,$01,$FF
 .db $CF,$BF,$FF,$F7,$FF,$FC,$3F,$FF
 .db $FF,$FC,$00,$00,$3F,$FF,$FB,$FF
 .db $FF,$FC,$38,$91,$FF,$03,$00,$00
 .db $3D,$FF,$F9,$91,$FF,$03,$BF,$91
 .db $FF,$03,$F9,$00,$3E,$FF,$FB,$FF
 .db $FF,$FB,$91,$FF,$04,$AF,$C3,$07
 .db $3F,$FB,$FF,$FF,$FB,$8F,$91,$FF
 .db $03,$83,$BD,$80,$3F,$FB,$FF,$FF
 .db $98,$1F,$91,$FF,$03,$81,$99,$CF
 .db $BF,$FB,$FF,$FF,$DC,$1C,$91,$FF
 .db $03,$C0,$80,$FB,$FF,$FB,$FF,$FF
 .db $DC,$3C,$7F,$FF,$FF,$E0,$00,$1F
 .db $FF,$FB,$FF,$FF,$DC,$3C,$3F,$FF
 .db $FF,$E0,$00,$0D,$91,$FF,$04,$CB
 .db $FE,$BF,$FF,$FF,$F0,$01,$74,$BF
 .db $91,$FF,$03,$C0,$7E,$9F,$FF,$FF
 .db $F1,$82,$0C,$3F,$91,$FF,$04,$1E
 .db $07,$FF,$FF,$F8,$40,$18,$3F,$91
 .db $FF,$04,$FE,$03,$FF,$FF,$F8,$00
 .db $00,$3F,$91,$FF,$05,$E0,$FF,$FF
 .db $FE,$10,$00,$3F,$91,$FF,$05,$F8
 .db $3F,$FF,$FF,$C0,$00,$3F,$91,$FF
 .db $06,$9F,$FF,$FF,$C6,$E2,$7F,$91
 .db $FF,$06,$D7,$FF,$FF,$C6,$05,$91
 .db $FF,$04,$DF,$FD,$FF,$77,$FF,$FF
 .db $E6,$FD,$91,$FF,$04,$DF,$FD,$FC
 .db $73,$91,$FF,$09,$F8,$FC,$71,$91
 .db $FF,$09,$FE,$F8,$3D,$91,$FF,$09
 .db $FE,$F8,$3D,$91,$FF,$09,$FA,$91
 .db $FF,$0B,$FB,$91,$FF,$0B,$FD,$91
 .db $FF,$0D,$C7,$91,$FF,$E9
Frame34:
 .db $01
 .db $91,$00,$78,$01,$61,$C0,$20,$00
 .db $00,$04,$91,$00,$05,$01,$A1,$FE
 .db $08,$00,$00,$13,$80,$91,$00,$05
 .db $CD,$DE,$B8,$00,$00,$29,$80,$91
 .db $00,$05,$E9,$88,$20,$40,$00,$3E
 .db $F8,$01,$91,$00,$04,$08,$41,$90
 .db $40,$00,$03,$84,$31,$F8,$91,$00
 .db $03,$02,$89,$10,$00,$00,$3F,$C3
 .db $78,$66,$91,$00,$05,$20,$08,$00
 .db $0F,$BA,$B8,$01,$10,$00,$04,$08
 .db $02,$44,$84,$00,$00,$FD,$CF,$0E
 .db $2C,$80,$00,$A0,$01,$C3,$88,$00
 .db $00,$21,$E3,$FF,$C8,$80,$00,$88
 .db $01,$02,$A0,$00,$00,$7C,$FF,$C7
 .db $3F,$00,$04,$88,$01,$03,$C3,$00
 .db $00,$1F,$00,$3F,$BD,$C0,$06,$91
 .db $00,$03,$40,$91,$00,$03,$FB,$0B
 .db $C2,$C0,$04,$10,$00,$04,$91,$00
 .db $04,$2F,$C8,$F8,$C0,$02,$10,$00
 .db $04,$70,$91,$00,$03,$03,$BD,$81
 .db $C0,$02,$00,$00,$67,$F1,$91,$00
 .db $03,$01,$99,$CF,$40,$02,$00,$00
 .db $23,$10,$91,$00,$03,$40,$80,$FB
 .db $00,$02,$00,$00,$23,$60,$80,$00
 .db $00,$10,$01,$1C,$00,$04,$00,$00
 .db $23,$60,$80,$91,$00,$03,$01,$4C
 .db $91,$00,$04,$34,$A0,$91,$00,$04
 .db $02,$F5,$91,$00,$04,$3F,$81,$10
 .db $91,$00,$03,$41,$CC,$91,$00,$05
 .db $E1,$08,$00,$00,$02,$47,$E6,$91
 .db $00,$09,$07,$E7,$1A,$91,$00,$06
 .db $60,$91,$00,$03,$36,$B2,$91,$00
 .db $07,$40,$00,$01,$37,$30,$91,$00
 .db $07,$10,$00,$00,$39,$04,$80,$91
 .db $00,$03,$10,$00,$00,$10,$00,$00
 .db $39,$06,$80,$91,$00,$03,$20,$91
 .db $00,$05,$19,$02,$91,$00,$04,$20
 .db $00,$00,$08,$91,$00,$09,$06,$00
 .db $08,$91,$00,$0A,$04,$48,$91,$00
 .db $0A,$02,$42,$91,$00,$09,$04,$91
 .db $00,$19,$08,$91,$00,$17,$20,$91
 .db $00,$DD
Frame35:
 .db $01
 .db $91,$00,$78,$01,$C2,$07,$E0,$00
 .db $00,$2D,$F8,$00,$40,$91,$00,$03
 .db $41,$F0,$06,$00,$00,$33,$BF,$81
 .db $A6,$91,$00,$03,$27,$52,$77,$80
 .db $00,$11,$83,$81,$39,$91,$00,$03
 .db $10,$40,$00,$C0,$00,$3F,$F9,$FE
 .db $23,$00,$00,$01,$00,$38,$40,$00
 .db $00,$3F,$FB,$F1,$F9,$80,$00,$00
 .db $A3,$68,$90,$91,$00,$03,$44,$60
 .db $66,$FC,$91,$00,$03,$AC,$2B,$08
 .db $00,$01,$C0,$39,$01,$77,$80,$91
 .db $00,$03,$44,$0C,$00,$00,$FF,$F9
 .db $FE,$5B,$C0,$00,$64,$00,$C0,$00
 .db $00,$01,$A1,$E2,$1F,$C7,$C0,$00
 .db $8C,$01,$02,$A2,$00,$00,$40,$FF
 .db $D1,$FE,$C0,$00,$08,$01,$03,$C6
 .db $91,$00,$04,$BF,$ED,$C0,$91,$00
 .db $03,$01,$C0,$00,$00,$07,$02,$0B
 .db $FF,$C0,$00,$10,$00,$03,$80,$91
 .db $00,$03,$80,$0B,$FE,$00,$02,$10
 .db $00,$12,$C0,$91,$00,$07,$02,$00
 .db $00,$21,$E8,$91,$00,$05,$06,$40
 .db $02,$00,$00,$21,$22,$80,$00,$00
 .db $60,$00,$84,$40,$02,$00,$00,$20
 .db $D2,$C0,$00,$00,$10,$01,$CB,$00
 .db $04,$00,$00,$20,$82,$A0,$91,$00
 .db $04,$8D,$91,$00,$04,$36,$C0,$80
 .db $91,$00,$04,$F5,$80,$91,$00,$03
 .db $3C,$41,$91,$00,$03,$09,$85,$8C
 .db $91,$00,$05,$01,$91,$00,$03,$02
 .db $03,$E6,$91,$00,$05,$01,$02,$00
 .db $00,$01,$83,$1A,$91,$00,$06,$E0
 .db $80,$00,$00,$92,$B2,$91,$00,$06
 .db $04,$40,$00,$01,$0B,$30,$91,$00
 .db $07,$10,$00,$00,$81,$04,$80,$91
 .db $00,$03,$10,$00,$00,$10,$91,$00
 .db $03,$E6,$80,$91,$00,$05,$01,$91
 .db $00,$04,$02,$91,$00,$05,$01,$00
 .db $08,$91,$00,$09,$06,$0C,$0A,$91
 .db $00,$06,$03,$91,$00,$03,$04,$42
 .db $00,$00,$01,$91,$00,$03,$03,$91
 .db $00,$03,$06,$40,$91,$00,$06,$02
 .db $91,$00,$0E,$02,$91,$00,$25,$20
 .db $91,$00,$DD
Frame36:
 .db $01
 .db $91,$00,$79,$10,$60,$40,$00,$00
 .db $20,$03,$80,$40,$91,$00,$03,$20
 .db $91,$00,$07,$14,$91,$00,$06,$40
 .db $91,$00,$08,$08,$20,$91,$00,$03
 .db $01,$91,$00,$05,$02,$00,$20,$91
 .db $00,$03,$08,$91,$00,$06,$0C,$00
 .db $00,$08,$00,$08,$98,$40,$00,$04
 .db $00,$00,$02,$10,$0E,$84,$91,$00
 .db $03,$80,$91,$00,$06,$04,$00,$00
 .db $01,$00,$04,$91,$00,$04,$E4,$00
 .db $E0,$84,$91,$00,$03,$40,$91,$00
 .db $04,$0E,$01,$03,$80,$00,$00,$C0
 .db $80,$A8,$91,$00,$03,$88,$01,$03
 .db $E0,$00,$00,$60,$41,$20,$91,$00
 .db $05,$01,$C0,$91,$00,$03,$C0,$68
 .db $80,$00,$00,$10,$00,$03,$80,$00
 .db $00,$03,$00,$E2,$8A,$00,$02,$10
 .db $00,$12,$D0,$91,$00,$03,$80,$C6
 .db $8A,$00,$02,$00,$00,$20,$48,$91
 .db $00,$03,$80,$60,$85,$40,$02,$00
 .db $00,$20,$10,$40,$00,$00,$E0,$DF
 .db $07,$40,$02,$00,$00,$20,$50,$91
 .db $00,$03,$61,$FD,$0B,$00,$04,$00
 .db $00,$20,$00,$40,$00,$00,$61,$7E
 .db $0D,$91,$00,$04,$36,$60,$F0,$00
 .db $00,$70,$CC,$F5,$80,$91,$00,$03
 .db $3C,$40,$80,$00,$00,$31,$99,$8C
 .db $91,$00,$06,$0C,$00,$00,$1F,$DB
 .db $E6,$91,$00,$05,$01,$91,$00,$04
 .db $63,$9A,$91,$00,$06,$10,$00,$00
 .db $01,$C2,$B2,$91,$00,$07,$A0,$00
 .db $18,$89,$30,$91,$00,$0A,$81,$04
 .db $80,$91,$00,$06,$18,$91,$00,$03
 .db $26,$80,$91,$00,$0A,$02,$91,$00
 .db $13,$02,$91,$00,$0E,$01,$91,$00
 .db $03,$01,$91,$00,$04,$04,$91,$00
 .db $12,$02,$91,$00,$28,$60,$91,$00
 .db $DD
Frame37:
 .db $00
 .db $91,$FF,$7B,$C7,$FF,$FF,$C0,$00
 .db $19,$9B,$00,$3F,$F8,$1F,$91,$FF
 .db $04,$F0,$00,$1E,$FB,$10,$3F,$F8
 .db $1F,$CF,$FE,$1F,$FF,$FD,$C0,$00
 .db $63,$00,$3F,$FE,$CB,$9F,$FE,$1F
 .db $FF,$FE,$FF,$13,$01,$DD,$FF,$FB
 .db $C0,$1F,$CF,$FF,$FF,$EE,$04,$D7
 .db $99,$FE,$FF,$FF,$FC,$99,$CF,$FF
 .db $FF,$F0,$06,$FC,$7F,$FC,$3F,$FF
 .db $FF,$86,$0E,$B9,$FF,$F0,$06,$08
 .db $0B,$F7,$91,$FF,$05,$FD,$FF,$FE
 .db $00,$78,$73,$03,$FF,$FF,$AF,$FF
 .db $FA,$98,$FF,$FF,$00,$00,$60,$00
 .db $3F,$FF,$BF,$FF,$FF,$DC,$FF,$FF
 .db $E0,$40,$64,$00,$3F,$FF,$BB,$FF
 .db $FF,$EF,$FF,$FF,$F0,$20,$73,$00
 .db $3F,$91,$FF,$07,$FE,$00,$00,$83
 .db $91,$FF,$05,$DF,$FF,$FF,$FE,$00
 .db $02,$8B,$FF,$F9,$FF,$FF,$FE,$0F
 .db $91,$FF,$03,$00,$06,$8B,$FF,$F9
 .db $FF,$FF,$FE,$BE,$91,$FF,$03,$80
 .db $00,$83,$FF,$F9,$FF,$FF,$EF,$FE
 .db $91,$FF,$03,$84,$07,$83,$FF,$F9
 .db $FF,$FF,$DF,$FE,$7F,$FF,$FF,$80
 .db $05,$C3,$91,$FF,$05,$FE,$7F,$FF
 .db $FF,$C9,$C7,$C1,$91,$FF,$05,$FE
 .db $7F,$FF,$FF,$E0,$87,$81,$BF,$91
 .db $FF,$04,$FE,$3F,$FF,$FF,$E3,$DB
 .db $C0,$3F,$91,$FF,$04,$FE,$1F,$FF
 .db $FF,$F0,$DF,$7E,$91,$FF,$05,$FE
 .db $0F,$FF,$FF,$F0,$1C,$43,$91,$FF
 .db $09,$F3,$FF,$7F,$91,$FF,$06,$FD
 .db $FF,$FF,$9B,$FF,$7F,$91,$FF,$07
 .db $BF,$91,$FF,$0B,$C7,$91,$FF,$09
 .db $FD,$FC,$77,$91,$FF,$09,$FC,$FC
 .db $73,$91,$FF,$09,$FA,$FB,$33,$91
 .db $FF,$09,$FE,$FF,$37,$91,$FF,$09
 .db $FE,$FD,$3B,$91,$FF,$15,$F9,$91
 .db $FF,$0D,$F7,$91,$FF,$0B,$C7,$91
 .db $FF,$0B,$DF,$91,$FF,$DD
Frame38:
 .db $01
 .db $91,$00,$7B,$38,$91,$00,$04,$18
 .db $02,$30,$00,$07,$20,$91,$00,$05
 .db $C0,$1E,$FD,$2F,$C0,$00,$20,$00
 .db $01,$80,$00,$02,$0F,$00,$63,$07
 .db $00,$06,$E8,$50,$91,$00,$04,$D2
 .db $D4,$41,$DC,$40,$00,$20,$90,$2C
 .db $20,$00,$02,$04,$28,$66,$C2,$C0
 .db $04,$01,$16,$20,$91,$00,$03,$06
 .db $FC,$A6,$03,$C0,$00,$00,$06,$80
 .db $80,$00,$00,$06,$08,$0B,$F6,$C0
 .db $00,$00,$3C,$F1,$84,$91,$00,$03
 .db $78,$7F,$03,$C0,$00,$4E,$08,$04
 .db $C0,$91,$00,$04,$60,$91,$00,$03
 .db $40,$00,$00,$80,$91,$00,$03,$40
 .db $6C,$91,$00,$03,$40,$00,$00,$90
 .db $91,$00,$03,$20,$7B,$91,$00,$05
 .db $01,$90,$91,$00,$05,$83,$91,$00
 .db $04,$01,$50,$91,$00,$04,$02,$8A
 .db $80,$02,$00,$00,$08,$91,$00,$05
 .db $06,$8A,$00,$02,$00,$00,$10,$91
 .db $00,$06,$85,$40,$02,$00,$00,$30
 .db $91,$00,$04,$04,$07,$07,$40,$02
 .db $00,$00,$20,$91,$00,$05,$05,$0B
 .db $00,$04,$91,$00,$07,$01,$C6,$0D
 .db $91,$00,$04,$60,$91,$00,$05,$86
 .db $F5,$80,$91,$00,$03,$60,$91,$00
 .db $04,$04,$00,$BC,$91,$00,$0B,$80
 .db $80,$91,$00,$09,$03,$BC,$91,$00
 .db $0B,$80,$91,$00,$0B,$80,$91,$00
 .db $11,$02,$00,$08,$91,$00,$21,$02
 .db $91,$00,$08,$02,$91,$00,$03,$03
 .db $91,$00,$07,$02,$91,$00,$03,$01
 .db $04,$91,$00,$09,$04,$91,$00,$0E
 .db $20,$91,$00,$0A,$08,$91,$00,$17
 .db $20,$91,$00,$DD
Frame39:
 .db $00
 .db $91,$FF,$78,$F9,$C0,$3F,$E0,$91
 .db $00,$07,$3F,$F8,$91,$00,$0A,$3F
 .db $F8,$91,$00,$0A,$3F,$F8,$91,$00
 .db $0A,$3F,$F8,$91,$00,$0A,$3F,$F8
 .db $91,$00,$0A,$3F,$F8,$91,$00,$0A
 .db $3F,$F8,$91,$00,$0A,$3F,$F8,$91
 .db $00,$0A,$3F,$F8,$91,$00,$0A,$3F
 .db $F8,$00,$7E,$91,$00,$08,$3F,$F8
 .db $00,$FF,$E0,$91,$00,$07,$3F,$F9
 .db $F0,$FF,$F0,$91,$00,$07,$3F,$FB
 .db $FF,$FF,$F8,$91,$00,$07,$3F,$FA
 .db $07,$FF,$F8,$91,$00,$07,$3F,$FB
 .db $07,$FF,$F8,$91,$00,$07,$3F,$FC
 .db $07,$FF,$FF,$91,$00,$07,$3F,$F9
 .db $91,$FF,$03,$91,$00,$07,$3F,$F8
 .db $3F,$FF,$FE,$FC,$91,$00,$06,$3F
 .db $F8,$3F,$FF,$FF,$FC,$91,$00,$06
 .db $3F,$F8,$3F,$FF,$FF,$FC,$91,$00
 .db $03,$08,$00,$00,$3F,$FF,$E7,$91
 .db $FF,$03,$91,$00,$03,$1E,$00,$00
 .db $3F,$F8,$E1,$9F,$FF,$C0,$00,$01
 .db $C0,$91,$00,$03,$3F,$FF,$80,$3F
 .db $FF,$C0,$00,$03,$C0,$00,$00,$05
 .db $3F,$F9,$80,$7F,$FF,$F0,$00,$0F
 .db $C0,$91,$00,$03,$3F,$F9,$0F,$FF
 .db $FF,$E0,$00,$3F,$80,$91,$00,$03
 .db $3F,$F8,$91,$FF,$03,$F8,$7F,$FF
 .db $91,$00,$04,$3F,$91,$FF,$04,$FE
 .db $FF,$FE,$91,$00,$04,$3F,$91,$FF
 .db $06,$F0,$91,$00,$04,$3F,$FF,$BF
 .db $91,$FF,$04,$80,$91,$00,$04,$3F
 .db $FF,$FF,$C7,$FF,$FF,$FE,$40,$91
 .db $00,$04,$3F,$91,$FF,$06,$91,$00
 .db $05,$3F,$91,$FF,$06,$C0,$91,$00
 .db $04,$3F,$91,$FF,$06,$E0,$91,$00
 .db $04,$3F,$91,$FF,$03,$7F,$7F,$FF
 .db $F0,$91,$00,$04,$3F,$FD,$FF,$FF
 .db $7F,$DF,$FF,$F3,$C0,$91,$00,$03
 .db $3F,$FF,$7F,$91,$FF,$04,$FB,$FF
 .db $80,$00,$00,$3F,$FF,$1F,$91,$FF
 .db $06,$FC,$00,$00,$3F,$FB,$07,$3F
 .db $91,$FF,$06,$F8,$00,$3F,$F8,$0D
 .db $3F,$91,$FF,$07,$C0,$3F,$F8,$0C
 .db $0F,$FB,$91,$FF,$06,$F8,$3F,$F8
 .db $1F,$03,$FC,$91,$FF,$05,$FD,$FF
 .db $BF,$F8,$1F,$80,$3E,$7F,$FF,$FF
 .db $DF,$FF,$FF,$F1,$FF,$FC,$0F,$E0
 .db $1F,$7F,$FF,$FF,$EF,$91,$FF,$05
 .db $CF,$F4,$0F,$3F,$FF,$FF,$E7,$91
 .db $FF,$70
Frame40:
 .db $01
 .db $91,$00,$78,$06,$3F,$C0,$1F,$FF
 .db $47,$C0,$00,$01,$C7,$70,$91,$00
 .db $10,$20,$91,$00,$03,$0F,$F8,$91
 .db $00,$4D,$3E,$91,$00,$0B,$40,$91
 .db $00,$0A,$06,$91,$00,$0B,$0E,$00
 .db $10,$91,$00,$08,$02,$91,$00,$0B
 .db $01,$91,$00,$0B,$01,$91,$00,$0B
 .db $02,$0C,$00,$00,$40,$91,$00,$07
 .db $04,$91,$00,$03,$40,$91,$00,$0A
 .db $01,$91,$00,$15,$40,$00,$00,$02
 .db $91,$00,$03,$08,$91,$00,$04,$08
 .db $91,$00,$0B,$21,$80,$00,$10,$91
 .db $00,$08,$80,$00,$00,$20,$91,$00
 .db $06,$80,$91,$00,$06,$20,$91,$00
 .db $03,$02,$91,$00,$07,$40,$91,$00
 .db $03,$08,$91,$00,$08,$20,$91,$00
 .db $18,$10,$91,$00,$09,$40,$00,$20
 .db $91,$00,$05,$04,$00,$00,$01,$91
 .db $00,$0C,$40,$91,$00,$29,$04,$91
 .db $00,$05,$08,$91,$00,$1A,$60,$91
 .db $00,$0F,$0C,$91,$00,$20,$02,$91
 .db $00,$03,$80,$91,$00,$17,$0A,$00
 .db $00,$20,$91,$00,$72
Frame41:
 .db $01
 .db $91,$00,$78,$06,$3F,$C0,$1F,$FF
 .db $47,$C0,$00,$01,$C7,$70,$91,$00
 .db $10,$20,$91,$00,$03,$0F,$F8,$91
 .db $00,$35,$1E,$91,$00,$0B,$3E,$91
 .db $00,$0B,$41,$80,$91,$00,$0A,$41
 .db $C0,$91,$00,$09,$05,$00,$10,$91
 .db $00,$09,$09,$00,$18,$91,$00,$08
 .db $02,$91,$00,$0B,$01,$18,$91,$00
 .db $0D,$07,$80,$91,$00,$07,$04,$34
 .db $00,$00,$BC,$91,$00,$07,$06,$A0
 .db $00,$00,$BC,$91,$00,$08,$60,$91
 .db $00,$04,$02,$40,$91,$00,$08,$02
 .db $00,$07,$C0,$91,$00,$04,$01,$AC
 .db $00,$00,$3E,$00,$FF,$C0,$91,$00
 .db $04,$06,$1F,$E0,$00,$1F,$01,$7F
 .db $C0,$91,$00,$05,$20,$20,$00,$20
 .db $01,$FE,$40,$91,$00,$04,$06,$00
 .db $40,$00,$18,$1F,$FD,$C0,$00,$00
 .db $07,$80,$01,$80,$00,$00,$08,$7F
 .db $D1,$C0,$00,$00,$01,$00,$01,$10
 .db $00,$00,$1F,$FF,$BF,$80,$00,$00
 .db $08,$00,$03,$91,$00,$03,$07,$80
 .db $FF,$20,$91,$00,$08,$01,$02,$FE
 .db $91,$00,$0B,$F0,$00,$10,$91,$00
 .db $04,$58,$91,$00,$06,$20,$91,$00
 .db $05,$3C,$91,$00,$03,$A0,$91,$00
 .db $08,$80,$00,$00,$B8,$91,$00,$0B
 .db $3E,$91,$00,$0B,$1E,$80,$91,$00
 .db $07,$80,$80,$00,$0F,$EC,$91,$00
 .db $04,$06,$00,$00,$88,$20,$00,$04
 .db $3F,$80,$91,$00,$04,$80,$00,$04
 .db $00,$00,$04,$00,$78,$91,$00,$04
 .db $E0,$00,$C0,$91,$00,$04,$02,$50
 .db $00,$00,$04,$F0,$C0,$60,$01,$91
 .db $00,$04,$07,$F0,$00,$07,$F6,$C0
 .db $00,$00,$FC,$91,$00,$04,$3F,$00
 .db $07,$FD,$F0,$04,$00,$48,$91,$00
 .db $04,$07,$C0,$03,$E3,$F8,$03,$91
 .db $00,$03,$04,$00,$02,$02,$40,$00
 .db $E1,$79,$C1,$80,$00,$00,$20,$00
 .db $00,$0E,$00,$04,$70,$D8,$E0,$80
 .db $00,$00,$12,$91,$00,$04,$05,$C8
 .db $3E,$70,$C0,$20,$00,$18,$00,$00
 .db $03,$C0,$91,$00,$6C
Frame42:
 .db $00
 .db $91,$FF,$FF,$FF,$FF,$FB,$91,$FF
 .db $23,$79,$91,$FF,$0B,$7B,$F7,$91
 .db $FF,$09,$FE,$3F,$91,$FF,$0B,$3D
 .db $EF,$91,$FF,$0A,$BF,$0F,$91,$FF
 .db $0A,$8F,$0F,$91,$FF,$09,$FE,$91
 .db $FF,$1F,$F9,$91,$FF,$17,$F9,$91
 .db $FF,$5F,$F9,$91,$FF,$0B,$F9,$91
 .db $FF,$EF
Frame43:
 .db $01
 .db $91,$00,$FF,$91,$00,$0E,$04,$91
 .db $00,$0B,$40,$91,$00,$0B,$40,$08
 .db $91,$00,$0A,$44,$91,$00,$0A,$01
 .db $00,$2C,$00,$00,$10,$91,$00,$07
 .db $02,$91,$00,$17,$71,$F0,$91,$00
 .db $09,$01,$91,$00,$13,$04,$91,$00
 .db $17,$04,$91,$00,$0B,$02,$91,$00
 .db $5F,$06,$91,$00,$0B,$06,$91,$00
 .db $59,$04,$91,$00,$95
Frame44:
 .db $00
 .db $91,$FF,$FF,$FF,$FF,$FB,$91,$FF
 .db $17,$BF,$91,$FF,$0B,$39,$F7,$91
 .db $FF,$0A,$33,$EF,$91,$FF,$0A,$BF
 .db $91,$FF,$0C,$F7,$91,$FF,$35,$FB
 .db $91,$FF,$23,$FD,$91,$FF,$FF,$91
 .db $FF,$5C
Frame45:
 .db $00
 .db $91,$FF,$FF,$91,$FF,$FF,$91,$FF
 .db $FF,$91,$FF,$03
Frame46:
 .db $01
 .db $91,$00,$FF,$91,$00,$FF,$91,$00
 .db $FF,$91,$00,$03
Frame47:
 .db $01
 .db $91,$00,$FF,$91,$00,$FF,$91,$00
 .db $FF,$91,$00,$03
Frame48:
 .db $01
 .db $91,$00,$79,$3F,$91,$FF,$08,$DF
 .db $C0,$04,$FF,$8B,$8F,$91,$FF,$03
 .db $F7,$91,$FF,$03,$C0,$04,$1F,$F3
 .db $2F,$91,$FF,$03,$DF,$91,$FF,$03
 .db $C0,$04,$3F,$91,$FF,$09,$C0,$07
 .db $3F,$91,$FF,$09,$C0,$07,$BF,$91
 .db $FF,$09,$C0,$07,$BF,$91,$FF,$09
 .db $C0,$07,$BF,$91,$FF,$09,$C0,$07
 .db $DF,$91,$FF,$09,$C0,$07,$DF,$91
 .db $FF,$09,$C0,$07,$DF,$91,$FF,$09
 .db $C0,$07,$DF,$91,$FF,$09,$C0,$07
 .db $DF,$91,$FF,$09,$C0,$07,$DF,$91
 .db $FF,$09,$C0,$07,$DF,$91,$FF,$09
 .db $C0,$07,$DF,$91,$FF,$09,$40,$07
 .db $5F,$91,$FF,$08,$FC,$40,$06,$BF
 .db $91,$FF,$08,$F8,$40,$07,$3F,$91
 .db $FF,$08,$FB,$C0,$07,$1F,$91,$FF
 .db $08,$FC,$C0,$07,$C7,$C4,$1F,$91
 .db $FF,$07,$C0,$07,$F0,$0F,$E7,$91
 .db $FF,$07,$C0,$07,$F7,$7F,$F7,$91
 .db $FF,$07,$C0,$07,$F5,$FF,$FD,$91
 .db $FF,$07,$C0,$07,$F3,$FF,$FE,$7F
 .db $91,$FF,$06,$C0,$07,$91,$FF,$0A
 .db $C0,$07,$91,$FF,$03,$3F,$91,$FF
 .db $06,$C0,$07,$91,$FF,$03,$9F,$91
 .db $FF,$06,$C0,$07,$91,$FF,$03,$CF
 .db $91,$FF,$04,$F3,$00,$00,$07,$91
 .db $FF,$03,$F5,$91,$FF,$04,$D0,$00
 .db $00,$07,$91,$FF,$03,$F8,$91,$FF
 .db $04,$80,$00,$00,$07,$91,$FF,$03
 .db $FA,$91,$FF,$03,$F8,$91,$00,$03
 .db $07,$91,$FF,$03,$FB,$BF,$FF,$FF
 .db $91,$00,$04,$07,$91,$FF,$06,$DC
 .db $91,$00,$04,$07,$7F,$91,$FF,$05
 .db $A0,$91,$00,$05,$1F,$91,$FF,$05
 .db $91,$00,$08,$0E,$1F,$FF,$F8,$91
 .db $00,$09,$07,$E0,$91,$00,$0A,$03
 .db $C0,$91,$00,$09,$1F,$00,$C0,$91
 .db $00,$09,$7F,$00,$E0,$91,$00,$09
 .db $03,$80,$08,$91,$00,$18,$30,$91
 .db $00,$7D
Frame49:
 .db $00
 .db $91,$FF,$78,$FE,$91,$00,$08,$02
 .db $24,$3F,$FB,$C0,$74,$70,$91,$00
 .db $03,$08,$91,$00,$03,$3F,$FC,$00
 .db $0C,$D0,$91,$00,$03,$20,$91,$00
 .db $03,$3F,$FC,$91,$00,$0A,$3F,$FC
 .db $91,$00,$0A,$3F,$FC,$91,$00,$0A
 .db $3F,$F8,$91,$00,$0A,$3F,$F8,$91
 .db $00,$0A,$3F,$F8,$91,$00,$0A,$3F
 .db $F8,$91,$00,$0A,$3F,$F8,$91,$00
 .db $0A,$3F,$F8,$07,$91,$00,$09,$3F
 .db $F8,$0F,$E0,$91,$00,$08,$3F,$F8
 .db $0F,$FC,$91,$00,$08,$3F,$F8,$0F
 .db $FC,$91,$00,$06,$E0,$00,$3F,$FC
 .db $1F,$FC,$91,$00,$06,$30,$00,$3F
 .db $FC,$07,$FF,$60,$91,$00,$04,$01
 .db $C0,$00,$3F,$91,$FF,$03,$E0,$91
 .db $00,$04,$01,$00,$00,$3F,$FB,$FF
 .db $FF,$F8,$91,$00,$04,$03,$00,$02
 .db $3F,$FD,$FF,$FF,$F8,$91,$00,$07
 .db $91,$FF,$04,$F8,$91,$00,$06,$18
 .db $BF,$F9,$FF,$FF,$FC,$91,$00,$06
 .db $18,$7F,$FF,$7F,$FF,$F8,$91,$00
 .db $06,$28,$7F,$FB,$1F,$FF,$FE,$91
 .db $00,$06,$10,$3F,$F9,$DF,$FF,$FE
 .db $91,$00,$07,$3F,$F8,$37,$FF,$FE
 .db $91,$00,$07,$3F,$F8,$53,$FF,$F8
 .db $91,$00,$04,$03,$C0,$40,$3F,$F8
 .db $00,$7F,$C0,$91,$00,$07,$3F,$F8
 .db $00,$1F,$FF,$FF,$F1,$FF,$00,$03
 .db $7A,$0C,$3F,$F8,$00,$87,$91,$FF
 .db $04,$10,$04,$28,$FF,$FF,$F9,$F8
 .db $08,$91,$FF,$03,$FC,$00,$80,$0F
 .db $FF,$FF,$F8,$7F,$91,$FF,$04,$F0
 .db $00,$01,$91,$FF,$09,$F8,$00,$BF
 .db $91,$FF,$0F,$F8,$7F,$91,$FF,$0A
 .db $F8,$1F,$91,$FF,$0A,$F8,$03,$91
 .db $FF,$0A,$F8,$00,$91,$FF,$0A,$F8
 .db $00,$3F,$91,$FF,$09,$F8,$00,$0F
 .db $91,$FF,$0A,$00,$01,$91,$FF,$0B
 .db $00,$3F,$91,$FF,$0A,$C0,$0F,$91
 .db $FF,$04,$F7,$91,$FF,$05,$F8,$03
 .db $91,$FF,$04,$F9,$91,$FF,$06,$00
 .db $3F,$91,$FF,$03,$F8,$7F,$91,$FF
 .db $6E
Frame50:
 .db $00
 .db $91,$FF,$78,$FE,$91,$00,$07,$88
 .db $8A,$21,$FF,$FB,$C0,$01,$E0,$91
 .db $00,$07,$3F,$F8,$91,$00,$0A,$3F
 .db $FC,$91,$00,$0A,$3F,$F8,$91,$00
 .db $0A,$3F,$F8,$91,$00,$0A,$3F,$F8
 .db $00,$06,$91,$00,$08,$3F,$F8,$00
 .db $06,$91,$00,$08,$3F,$F8,$91,$00
 .db $0A,$3F,$F8,$91,$00,$0A,$3F,$F8
 .db $00,$40,$91,$00,$08,$3F,$F8,$00
 .db $C0,$91,$00,$08,$3F,$F8,$91,$00
 .db $0A,$3F,$F8,$91,$00,$08,$01,$FF
 .db $3F,$F8,$91,$00,$08,$03,$C0,$3F
 .db $F8,$91,$00,$03,$58,$40,$91,$00
 .db $03,$04,$00,$3F,$F8,$91,$00,$03
 .db $38,$91,$00,$06,$3F,$F8,$91,$00
 .db $03,$18,$91,$00,$05,$60,$3F,$F8
 .db $91,$00,$0A,$3F,$F8,$91,$00,$04
 .db $60,$91,$00,$05,$3F,$F8,$91,$00
 .db $03,$06,$7E,$91,$00,$05,$3F,$F8
 .db $91,$00,$03,$07,$FF,$91,$00,$05
 .db $3F,$F8,$91,$00,$03,$03,$FF,$00
 .db $04,$91,$00,$03,$3F,$FA,$C0,$91
 .db $00,$03,$FF,$B0,$00,$18,$00,$00
 .db $FF,$F8,$40,$00,$00,$1E,$FF,$FE
 .db $00,$03,$80,$00,$3F,$FC,$10,$08
 .db $00,$3F,$FF,$FF,$91,$00,$04,$3F
 .db $FE,$09,$8C,$00,$1F,$FF,$FF,$00
 .db $00,$80,$00,$3F,$F8,$84,$40,$80
 .db $0F,$FF,$FF,$91,$00,$04,$3F,$F8
 .db $80,$00,$40,$1F,$FF,$FC,$91,$00
 .db $04,$3F,$F8,$00,$48,$20,$6F,$FF
 .db $FF,$91,$00,$04,$FF,$F8,$01,$80
 .db $18,$67,$FF,$FF,$80,$91,$00,$03
 .db $3F,$F9,$00,$18,$0E,$87,$FF,$FF
 .db $80,$00,$00,$01,$FF,$FE,$00,$C0
 .db $1A,$C1,$FF,$FF,$80,$00,$00,$02
 .db $FF,$F8,$51,$08,$51,$F1,$FF,$FD
 .db $80,$00,$00,$58,$3F,$F8,$03,$80
 .db $00,$01,$FF,$FC,$C0,$01,$F9,$FC
 .db $3F,$F8,$36,$38,$00,$1B,$91,$FF
 .db $05,$F3,$3F,$F8,$10,$07,$C2,$91
 .db $FF,$03,$80,$3F,$FF,$CF,$FF,$F8
 .db $6F,$C0,$93,$9F,$FF,$FF,$83,$91
 .db $FF,$07,$C7,$93,$3F,$3B,$91,$FF
 .db $08,$FE,$A7,$DD,$91,$FF,$0B,$EC
 .db $91,$FF,$0A,$E2,$1F,$91,$FF,$0A
 .db $E3,$91,$FF,$0B,$9F,$91,$FF,$7F
Frame51:
 .db $01
 .db $91,$00,$79,$60,$02,$30,$03,$22
 .db $22,$02,$8A,$A9,$61,$C0,$00,$3F
 .db $FE,$16,$01,$9B,$08,$B8,$91,$00
 .db $04,$06,$60,$00,$36,$09,$99,$88
 .db $20,$00,$00,$02,$00,$02,$60,$00
 .db $30,$00,$10,$91,$00,$52,$0C,$91
 .db $00,$0A,$40,$18,$91,$00,$10,$03
 .db $C0,$91,$00,$05,$60,$91,$00,$04
 .db $1E,$03,$91,$00,$07,$0F,$80,$00
 .db $07,$C0,$91,$00,$03,$02,$00,$20
 .db $10,$91,$00,$03,$24,$03,$C0,$91
 .db $00,$04,$20,$91,$00,$05,$01,$C0
 .db $91,$00,$09,$02,$18,$91,$00,$07
 .db $0C,$91,$00,$0A,$30,$91,$00,$0A
 .db $06,$6E,$91,$00,$0A,$07,$1F,$91
 .db $00,$0A,$03,$03,$00,$04,$91,$00
 .db $04,$02,$C0,$91,$00,$03,$01,$B0
 .db $00,$98,$00,$7E,$C0,$00,$40,$00
 .db $00,$19,$40,$FE,$00,$03,$80,$E1
 .db $00,$01,$10,$08,$00,$38,$00,$3F
 .db $91,$00,$03,$40,$00,$06,$49,$8C
 .db $00,$1E,$00,$21,$00,$00,$81,$C0
 .db $00,$07,$A4,$40,$81,$90,$91,$00
 .db $04,$01,$00,$00,$01,$98,$00,$47
 .db $A0,$00,$03,$00,$00,$01,$20,$00
 .db $00,$04,$48,$2C,$70,$91,$00,$04
 .db $01,$DC,$C0,$00,$06,$00,$10,$68
 .db $00,$0F,$80,$00,$00,$60,$00,$01
 .db $10,$18,$36,$A8,$00,$00,$80,$00
 .db $00,$11,$C0,$06,$00,$C0,$2A,$C2
 .db $91,$00,$05,$72,$C0,$00,$51,$70
 .db $11,$F3,$00,$02,$00,$00,$03,$2C
 .db $00,$00,$03,$13,$C0,$00,$00,$02
 .db $40,$01,$F8,$0C,$00,$00,$36,$37
 .db $C0,$3B,$00,$03,$00,$60,$00,$03
 .db $00,$00,$10,$06,$42,$80,$00,$00
 .db $7F,$C0,$00,$4B,$C0,$00,$6F,$C0
 .db $BC,$A0,$00,$00,$03,$00,$00,$03
 .db $C0,$07,$FF,$FF,$C7,$7C,$C0,$C4
 .db $B0,$00,$00,$03,$C0,$07,$FF,$FC
 .db $01,$08,$22,$40,$91,$00,$05,$07
 .db $FF,$EE,$FF,$EF,$ED,$91,$00,$06
 .db $07,$FF,$FE,$00,$A3,$E0,$01,$80
 .db $91,$00,$05,$30,$00,$00,$1F,$F9
 .db $91,$00,$0A,$60,$80,$91,$00,$0A
 .db $02,$91,$00,$73
Frame52:
 .db $01
 .db $91,$00,$7F,$02,$02,$91,$00,$0A
 .db $08,$91,$00,$1A,$40,$91,$00,$69
 .db $03,$C3,$C0,$91,$00,$09,$1F,$EF
 .db $FC,$91,$00,$09,$10,$04,$91,$00
 .db $04,$02,$91,$00,$06,$20,$C3,$C0
 .db $91,$00,$0A,$01,$C0,$91,$00,$09
 .db $0A,$78,$91,$00,$07,$0C,$00,$03
 .db $C0,$91,$00,$0A,$02,$91,$00,$0B
 .db $02,$91,$00,$08,$E0,$91,$00,$0B
 .db $20,$91,$00,$0B,$3E,$91,$00,$03
 .db $21,$7E,$91,$00,$05,$07,$41,$00
 .db $18,$00,$20,$E1,$00,$05,$91,$00
 .db $03,$01,$80,$C0,$08,$00,$20,$40
 .db $00,$00,$40,$00,$00,$07,$80,$7B
 .db $E8,$00,$21,$C4,$00,$07,$20,$02
 .db $00,$28,$00,$1F,$00,$00,$21,$00
 .db $00,$01,$18,$03,$B9,$A2,$91,$00
 .db $04,$21,$20,$00,$00,$04,$04,$0C
 .db $1F,$00,$00,$80,$00,$05,$DC,$00
 .db $00,$07,$88,$08,$31,$80,$0F,$80
 .db $00,$20,$60,$00,$05,$10,$08,$38
 .db $30,$91,$00,$04,$18,$10,$00,$03
 .db $00,$38,$30,$0C,$91,$00,$04,$78
 .db $70,$00,$00,$80,$68,$40,$0D,$00
 .db $00,$60,$0F,$03,$34,$00,$02,$40
 .db $93,$C0,$02,$00,$01,$61,$C7,$00
 .db $F0,$00,$02,$10,$02,$D8,$22,$00
 .db $03,$17,$9F,$FB,$CC,$00,$00,$04
 .db $2D,$87,$BE,$00,$01,$C4,$07,$E0
 .db $78,$00,$00,$03,$CE,$28,$A0,$00
 .db $00,$61,$00,$00,$3C,$91,$00,$03
 .db $40,$03,$F0,$00,$00,$8E,$91,$00
 .db $06,$53,$FF,$90,$00,$40,$91,$00
 .db $03,$02,$91,$00,$03,$5B,$02,$10
 .db $DA,$91,$00,$06,$01,$41,$01,$FC
 .db $BE,$0A,$01,$80,$91,$00,$04,$07
 .db $C4,$00,$00,$03,$C6,$C0,$91,$00
 .db $0A,$80,$91,$00,$0A,$02,$91,$00
 .db $73
Frame53:
 .db $00
 .db $91,$FF,$78,$FE,$60,$02,$30,$03
 .db $22,$22,$28,$01,$3B,$40,$3F,$FB
 .db $FF,$FF,$F6,$01,$9B,$0B,$B2,$20
 .db $00,$00,$3F,$FE,$60,$00,$36,$09
 .db $98,$0A,$02,$20,$00,$0A,$3F,$FE
 .db $60,$00,$30,$01,$10,$12,$07,$F8
 .db $00,$0A,$3F,$F8,$91,$00,$06,$0F
 .db $FC,$00,$00,$3F,$F8,$91,$00,$06
 .db $10,$B0,$00,$01,$BF,$F8,$00,$06
 .db $91,$00,$04,$20,$00,$00,$03,$BF
 .db $F8,$00,$06,$91,$00,$03,$01,$E0
 .db $91,$00,$03,$3F,$F8,$91,$00,$05
 .db $02,$A0,$91,$00,$03,$3F,$F8,$91
 .db $00,$05,$03,$80,$91,$00,$03,$3F
 .db $F8,$00,$40,$91,$00,$03,$74,$00
 .db $10,$00,$00,$3F,$F8,$00,$C7,$40
 .db $03,$FD,$FC,$00,$10,$00,$00,$3F
 .db $F8,$00,$07,$C2,$04,$09,$F8,$00
 .db $10,$00,$00,$3F,$F8,$00,$06,$00
 .db $6F,$DF,$F8,$00,$10,$00,$00,$3F
 .db $F8,$00,$18,$33,$E2,$7F,$F0,$91
 .db $00,$04,$3F,$F8,$00,$00,$08,$0F
 .db $FF,$F0,$00,$09,$00,$00,$3F,$F8
 .db $00,$02,$00,$0F,$FF,$E0,$00,$05
 .db $00,$00,$3F,$F8,$91,$00,$03,$0F
 .db $FF,$FC,$08,$04,$60,$00,$3F,$F8
 .db $91,$00,$03,$07,$FF,$FE,$00,$00
 .db $36,$00,$3F,$F8,$91,$00,$03,$07
 .db $FF,$FF,$CC,$03,$16,$00,$3F,$FB
 .db $80,$00,$00,$07,$FF,$FF,$04,$00
 .db $C2,$00,$3F,$FA,$80,$00,$00,$7F
 .db $FF,$F9,$1C,$00,$63,$00,$3F,$FA
 .db $02,$00,$00,$8F,$FF,$FF,$00,$00
 .db $21,$00,$3F,$FA,$00,$80,$00,$63
 .db $FF,$FE,$7C,$00,$10,$00,$3F,$F8
 .db $91,$00,$03,$02,$FF,$FF,$40,$00
 .db $10,$00,$3F,$FA,$60,$00,$01,$81
 .db $FF,$FF,$C0,$91,$00,$03,$3F,$FF
 .db $FF,$91,$00,$03,$FF,$FE,$91,$00
 .db $03,$18,$3F,$91,$FF,$03,$FE,$C0
 .db $FF,$FF,$91,$00,$03,$62,$91,$FF
 .db $07,$FE,$00,$00,$8D,$C1,$BF,$91
 .db $FF,$07,$F8,$00,$FF,$CF,$91,$FF
 .db $03,$FB,$FD,$EF,$91,$FF,$17,$FE
 .db $91,$FF,$08,$E0,$91,$FF,$04,$F7
 .db $A7,$FB,$91,$FF,$04,$DF,$91,$FF
 .db $0B,$F9,$91,$FF,$0C,$F9,$91,$FF
 .db $06,$DF,$91,$FF,$05,$80,$7F,$91
 .db $FF,$09,$FE,$00,$01,$91,$FF,$09
 .db $C4,$1F,$91,$FF,$0A,$FC,$7F,$91
 .db $FF,$0A,$E0,$3F,$91,$FF,$08,$FE
 .db $00,$01,$91,$FF,$09,$F8,$91,$FF
 .db $0B,$FE,$91,$FF,$77
Frame54:
 .db 0,0,0 ;end of video
 .db 0,0,0 ;end of video

.end
